@@ -1,7 +1,11 @@
 module.exports = {
 	root: true,
 	plugins: ["prettier", "node", "jest"],
-	extends: ["eslint:recommended", "plugin:node/recommended", "plugin:prettier/recommended"],
+	extends: [
+		"eslint:recommended",
+		"plugin:node/recommended",
+		"plugin:prettier/recommended"
+	],
 	env: {
 		node: true,
 		es6: true
@@ -16,10 +20,10 @@ module.exports = {
 		"no-template-curly-in-string": "error",
 		"no-caller": "error",
 		"no-control-regex": "off",
-		"yoda": "error",
-		"eqeqeq": "error",
+		yoda: "error",
+		eqeqeq: "error",
 		"global-require": "off",
-		"brace-style": "error",
+		"brace-style": "off",
 		"eol-last": "error",
 		"no-extra-bind": "warn",
 		"no-process-exit": "warn",
@@ -27,9 +31,26 @@ module.exports = {
 		"no-unused-vars": ["error", { args: "none" }],
 		"no-unsafe-negation": "error",
 		"no-loop-func": "warn",
-		"indent": "off",
+		indent: "off",
 		"no-console": "off",
-		"valid-jsdoc": "error",
+		"valid-jsdoc": [
+			"error",
+			{
+				prefer: {
+					return: "returns",
+					prop: "property",
+					memberof: "DONTUSE",
+					class: "DONTUSE",
+					inheritdoc: "DONTUSE",
+					description: "DONTUSE",
+					readonly: "DONTUSE"
+				},
+				preferType: {
+					"*": "any"
+				},
+				requireReturnType: true
+			}
+		],
 		"node/no-unsupported-features": "error",
 		"node/no-deprecated-api": "error",
 		"node/no-missing-import": "error",
@@ -46,7 +67,7 @@ module.exports = {
 				browser: true
 			},
 			globals: {
-				Promise: false,
+				Promise: false
 			},
 			parserOptions: {
 				ecmaVersion: 5
@@ -56,6 +77,9 @@ module.exports = {
 			files: ["test/**/*.js"],
 			env: {
 				"jest/globals": true
+			},
+			globals: {
+				nsObj: false
 			}
 		}
 	]
