@@ -1,8 +1,9 @@
 var path = require("path");
 module.exports = {
+	// mode: "development || "production",
 	entry: "./example",
 	output: {
-		path: path.join(__dirname, "js"),
+		path: path.join(__dirname, "dist"),
 		filename: "MyLibrary.umd.js",
 		library: "MyLibrary",
 		libraryTarget: "umd"
