@@ -1,11 +1,12 @@
 var path = require("path");
 module.exports = {
+	// mode: "development || "production",
 	entry: {
 		alpha: "./alpha",
 		beta: "./beta"
 	},
 	output: {
-		path: path.join(__dirname, "js"),
+		path: path.join(__dirname, "dist"),
 		filename: "MyLibrary.[name].js",
 		library: ["MyLibrary", "[name]"],
 		libraryTarget: "umd"
