@@ -23,10 +23,13 @@ if (module.hot) {
 					var status = module.hot.status();
 					if (["abort", "fail"].indexOf(status) >= 0) {
 						log("warning", "[HMR] Cannot apply update.");
-						log("warning", "[HMR] " + err.stack || err.message);
+						log("warning", "[HMR] " + (err.stack || err.message));
 						log("warning", "[HMR] You need to restart the application!");
 					} else {
-						log("warning", "[HMR] Update failed: " + err.stack || err.message);
+						log(
+							"warning",
+							"[HMR] Update failed: " + (err.stack || err.message)
+						);
 					}
 				});
 		}
