@@ -8,45 +8,57 @@ const util = require("util");
 const SortableSet = require("./util/SortableSet");
 const intersect = require("./util/SetHelpers").intersect;
 const GraphHelpers = require("./GraphHelpers");
+const Entrypoint = require("./Entrypoint");
 let debugId = 1000;
 const ERR_CHUNK_ENTRY = "Chunk.entry was removed. Use hasRuntime()";
 const ERR_CHUNK_INITIAL =
 	"Chunk.initial was removed. Use canBeInitial/isOnlyInitial()";
 
-/** @typedef {import("./Module.js")} Module */
+/** @typedef {import("./Module")} Module */
 /** @typedef {import("./ChunkGroup")} ChunkGroup */
-/** @typedef {import("./ModuleReason.js")} ModuleReason */
+/** @typedef {import("./ModuleReason")} ModuleReason */
 /** @typedef {import("webpack-sources").Source} Source */
+/** @typedef {import("./util/createHash").Hash} Hash */
 
 /**
- *  @typedef {Object} Identifiable an object who contains an identifier function property
- *  @property {() => string} identifier the resource or unique identifier of something
+ *  @typedef {Object} WithId an object who has an id property *
+ *  @property {string | number} id the id of the object
  */
 
 /**
- *  @typedef {Object} WithId an object who has an id property
- *  @property {string} id the id of the object
+ * Compare two Modules based on their ids for sorting
+ * @param {Module} a module
+ * @param {Module} b module
+ * @returns {-1|0|1} sort value
  */
 
+// TODO use @callback
 /** @typedef {(a: Module, b: Module) => -1|0|1} ModuleSortPredicate */
 /** @typedef {(m: Module) => boolean} ModuleFilterPredicate */
 /** @typedef {(c: Chunk) => boolean} ChunkFilterPredicate */
 
-/**
- * @param {WithId} a object that contains an ID property
- * @param {WithId} b object that contains an ID property
- * @returns {-1|0|1} sort value
- */
-const sortById = (a, b) => {
+const sortModuleById = (a, b) => {
 	if (a.id < b.id) return -1;
 	if (b.id < a.id) return 1;
 	return 0;
 };
 
 /**
- *
- * @param {Identifiable} a first object with ident fn
- * @param {Identifiable} b second object with ident fn
+ * Compare two ChunkGroups based on their ids for sorting
+ * @param {ChunkGroup} a chunk group
+ * @param {ChunkGroup} b chunk group
+ * @returns {-1|0|1} sort value
+ */
+const sortChunkGroupById = (a, b) => {
+	if (a.id < b.id) return -1;
+	if (b.id < a.id) return 1;
+	return 0;
+};
+
+/**
+ * Compare two Identifiables , based on their ids for sorting
+ * @param {Module} a first object with ident fn
+ * @param {Module} b second object with ident fn
  * @returns {-1|0|1} The order number of the sort
  */
 const sortByIdentifier = (a, b) => {
@@ -69,14 +81,14 @@ const getModulesIdent = set => {
 };
 
 /**
- * @template {T}
- * @param {Set<T>} set the set to convert to array
+ * @template T
+ * @param {SortableSet<T>} set the sortable set to convert to array
  * @returns {Array<T>} the array returned from Array.from(set)
  */
 const getArray = set => Array.from(set);
 
 /**
- * @param {Set<Module>} set the Set to get the count/size of
+ * @param {SortableSet<Module>} set the sortable Set to get the count/size of
  * @returns {number} the size of the modules
  */
 const getModulesSize = set => {
@@ -108,13 +120,13 @@ class Chunk {
 		this.preventIntegration = false;
 		/** @type {Module=} */
 		this.entryModule = undefined;
-		//TODO make these typed generics for Module[] and ChunkGroup[] and their sort being (T, T): => 1,-1,0
-		//See https://github.com/webpack/webpack/pull/7046
-		/** @private */
+		/** @private @type {SortableSet<Module>} */
 		this._modules = new SortableSet(undefined, sortByIdentifier);
-		/** @private */
-		this._groups = new SortableSet(undefined, sortById);
-		/** @type {Source[]} */
+		/** @type {string?} */
+		this.filenameTemplate = undefined;
+		/** @private @type {SortableSet<ChunkGroup>} */
+		this._groups = new SortableSet(undefined, sortChunkGroupById);
+		/** @type {string[]} */
 		this.files = [];
 		/** @type {boolean} */
 		this.rendered = false;
@@ -128,6 +140,7 @@ class Chunk {
 		this.chunkReason = undefined;
 		/** @type {boolean} */
 		this.extraAsync = false;
+		this.removedModules = undefined;
 	}
 
 	/**
@@ -169,8 +182,13 @@ class Chunk {
 	 */
 	hasRuntime() {
 		for (const chunkGroup of this._groups) {
-			// We only need to check the first one
-			return chunkGroup.isInitial() && chunkGroup.getRuntimeChunk() === this;
+			if (
+				chunkGroup.isInitial() &&
+				chunkGroup instanceof Entrypoint &&
+				chunkGroup.getRuntimeChunk() === this
+			) {
+				return true;
+			}
 		}
 		return false;
 	}
@@ -285,7 +303,7 @@ class Chunk {
 	}
 
 	/**
-	 * @returns {SortableSet} the chunkGroups that said chunk is referenced in
+	 * @returns {SortableSet<ChunkGroup>} the chunkGroups that said chunk is referenced in
 	 */
 	get groupsIterable() {
 		return this._groups;
@@ -296,17 +314,21 @@ class Chunk {
 	 * @returns {-1|0|1} this is a comparitor function like sort and returns -1, 0, or 1 based on sort order
 	 */
 	compareTo(otherChunk) {
-		this._modules.sort();
-		otherChunk._modules.sort();
+		if (this.name && !otherChunk.name) return -1;
+		if (!this.name && otherChunk.name) return 1;
+		if (this.name < otherChunk.name) return -1;
+		if (this.name > otherChunk.name) return 1;
 		if (this._modules.size > otherChunk._modules.size) return -1;
 		if (this._modules.size < otherChunk._modules.size) return 1;
+		this._modules.sort();
+		otherChunk._modules.sort();
 		const a = this._modules[Symbol.iterator]();
 		const b = otherChunk._modules[Symbol.iterator]();
-		// eslint-disable-next-line
+		// eslint-disable-next-line no-constant-condition
 		while (true) {
 			const aItem = a.next();
-			const bItem = b.next();
 			if (aItem.done) return 0;
+			const bItem = b.next();
 			const aModuleIdentifier = aItem.value.identifier();
 			const bModuleIdentifier = bItem.value.identifier();
 			if (aModuleIdentifier < bModuleIdentifier) return -1;
@@ -322,6 +344,9 @@ class Chunk {
 		return this._modules.has(module);
 	}
 
+	/**
+	 * @returns {Module[]} an array of modules (do not modify)
+	 */
 	getModules() {
 		return this._modules.getFromCache(getArray);
 	}
@@ -364,33 +389,48 @@ class Chunk {
 			return false;
 		}
 
+		// Pick a new name for the integrated chunk
+		if (this.name && otherChunk.name) {
+			if (this.hasEntryModule() === otherChunk.hasEntryModule()) {
+				// When both chunks have entry modules or none have one, use
+				// shortest name
+				if (this.name.length !== otherChunk.name.length) {
+					this.name =
+						this.name.length < otherChunk.name.length
+							? this.name
+							: otherChunk.name;
+				} else {
+					this.name = this.name < otherChunk.name ? this.name : otherChunk.name;
+				}
+			} else if (otherChunk.hasEntryModule()) {
+				// Pick the name of the chunk with the entry module
+				this.name = otherChunk.name;
+			}
+		} else if (otherChunk.name) {
+			this.name = otherChunk.name;
+		}
+
 		// Array.from is used here to create a clone, because moveModule modifies otherChunk._modules
 		for (const module of Array.from(otherChunk._modules)) {
 			otherChunk.moveModule(module, this);
 		}
 		otherChunk._modules.clear();
 
+		if (otherChunk.entryModule) {
+			this.entryModule = otherChunk.entryModule;
+		}
+
 		for (const chunkGroup of otherChunk._groups) {
 			chunkGroup.replaceChunk(otherChunk, this);
 			this.addGroup(chunkGroup);
 		}
 		otherChunk._groups.clear();
 
-		if (this.name && otherChunk.name) {
-			if (this.name.length !== otherChunk.name.length)
-				this.name =
-					this.name.length < otherChunk.name.length
-						? this.name
-						: otherChunk.name;
-			else
-				this.name = this.name < otherChunk.name ? this.name : otherChunk.name;
-		}
-
 		return true;
 	}
 
 	/**
-	 * @param {Chunk} newChunk the new chunk that will be split out of, and then chunk raphi twil=
+	 * @param {Chunk} newChunk the new chunk that will be split out of the current chunk
 	 * @returns {void}
 	 */
 	split(newChunk) {
@@ -414,28 +454,39 @@ class Chunk {
 	}
 
 	canBeIntegrated(otherChunk) {
+		if (this.preventIntegration || otherChunk.preventIntegration) {
+			return false;
+		}
+
 		const isAvailable = (a, b) => {
 			const queue = new Set(b.groupsIterable);
 			for (const chunkGroup of queue) {
 				if (a.isInGroup(chunkGroup)) continue;
 				if (chunkGroup.isInitial()) return false;
-				for (const parent of chunkGroup.parentsIterable) queue.add(parent);
+				for (const parent of chunkGroup.parentsIterable) {
+					queue.add(parent);
+				}
 			}
 			return true;
 		};
 
-		if (this.preventIntegration || otherChunk.preventIntegration) return false;
+		const selfHasRuntime = this.hasRuntime();
+		const otherChunkHasRuntime = otherChunk.hasRuntime();
 
-		if (this.hasRuntime() !== otherChunk.hasRuntime()) {
-			if (this.hasRuntime()) {
+		if (selfHasRuntime !== otherChunkHasRuntime) {
+			if (selfHasRuntime) {
 				return isAvailable(this, otherChunk);
-			} else if (otherChunk.hasRuntime()) {
+			} else if (otherChunkHasRuntime) {
 				return isAvailable(otherChunk, this);
 			} else {
 				return false;
 			}
 		}
-		if (this.hasEntryModule() || otherChunk.hasEntryModule()) return false;
+
+		if (this.hasEntryModule() || otherChunk.hasEntryModule()) {
+			return false;
+		}
+
 		return true;
 	}
 
@@ -466,10 +517,15 @@ class Chunk {
 	 * @param {Object} options the size display options
 	 * @returns {number} the chunk size
 	 */
-	size(options) {
+	size(options = {}) {
 		return this.addMultiplierAndOverhead(this.modulesSize(), options);
 	}
 
+	/**
+	 * @param {Chunk} otherChunk the other chunk
+	 * @param {TODO} options the options for this function
+	 * @returns {number | false} the size, or false if it can't be integrated
+	 */
 	integratedSize(otherChunk, options) {
 		// Chunk if it's possible to integrate this chunk
 		if (!this.canBeIntegrated(otherChunk)) {
@@ -488,17 +544,20 @@ class Chunk {
 	}
 
 	/**
-	 * @param {ModuleSortPredicate=} sortByFn a predicate function used to sort modules
+	 * @param {function(Module, Module): -1|0|1=} sortByFn a predicate function used to sort modules
 	 * @returns {void}
 	 */
 	sortModules(sortByFn) {
-		this._modules.sortWith(sortByFn || sortById);
+		this._modules.sortWith(sortByFn || sortModuleById);
 	}
 
-	sortItems(sortChunks) {
+	sortItems() {
 		this.sortModules();
 	}
 
+	/**
+	 * @returns {Set<Chunk>} a set of all the async chunks
+	 */
 	getAllAsyncChunks() {
 		const queue = new Set();
 		const chunks = new Set();
@@ -508,32 +567,55 @@ class Chunk {
 		);
 
 		for (const chunkGroup of this.groupsIterable) {
-			for (const child of chunkGroup.childrenIterable) queue.add(child);
+			for (const child of chunkGroup.childrenIterable) {
+				queue.add(child);
+			}
 		}
 
 		for (const chunkGroup of queue) {
 			for (const chunk of chunkGroup.chunks) {
-				if (!initialChunks.has(chunk)) chunks.add(chunk);
+				if (!initialChunks.has(chunk)) {
+					chunks.add(chunk);
+				}
+			}
+			for (const child of chunkGroup.childrenIterable) {
+				queue.add(child);
 			}
-			for (const child of chunkGroup.childrenIterable) queue.add(child);
 		}
 
 		return chunks;
 	}
 
+	/**
+	 * @typedef {Object} ChunkMaps
+	 * @property {Record<string|number, string>} hash
+	 * @property {Record<string|number, Record<string, string>>} contentHash
+	 * @property {Record<string|number, string>} name
+	 */
+
+	/**
+	 * @param {boolean} realHash should the full hash or the rendered hash be used
+	 * @returns {ChunkMaps} the chunk map information
+	 */
 	getChunkMaps(realHash) {
+		/** @type {Record<string|number, string>} */
 		const chunkHashMap = Object.create(null);
+		/** @type {Record<string|number, Record<string, string>>} */
 		const chunkContentHashMap = Object.create(null);
+		/** @type {Record<string|number, string>} */
 		const chunkNameMap = Object.create(null);
 
 		for (const chunk of this.getAllAsyncChunks()) {
 			chunkHashMap[chunk.id] = realHash ? chunk.hash : chunk.renderedHash;
 			for (const key of Object.keys(chunk.contentHash)) {
-				if (!chunkContentHashMap[key])
+				if (!chunkContentHashMap[key]) {
 					chunkContentHashMap[key] = Object.create(null);
+				}
 				chunkContentHashMap[key][chunk.id] = chunk.contentHash[key];
 			}
-			if (chunk.name) chunkNameMap[chunk.id] = chunk.name;
+			if (chunk.name) {
+				chunkNameMap[chunk.id] = chunk.name;
+			}
 		}
 
 		return {
@@ -543,6 +625,9 @@ class Chunk {
 		};
 	}
 
+	/**
+	 * @returns {Record<string, Set<TODO>[]>} a record object of names to lists of child ids(?)
+	 */
 	getChildIdsByOrders() {
 		const lists = new Map();
 		for (const group of this.groupsIterable) {
@@ -570,13 +655,17 @@ class Chunk {
 			list.sort((a, b) => {
 				const cmp = b.order - a.order;
 				if (cmp !== 0) return cmp;
-				// TOOD webpack 5 remove this check of compareTo
-				if (a.group.compareTo) return a.group.compareTo(b.group);
+				// TODO webpack 5 remove this check of compareTo
+				if (a.group.compareTo) {
+					return a.group.compareTo(b.group);
+				}
 				return 0;
 			});
 			result[name] = Array.from(
 				list.reduce((set, item) => {
-					for (const chunk of item.group.chunks) set.add(chunk.id);
+					for (const chunk of item.group.chunks) {
+						set.add(chunk.id);
+					}
 					return set;
 				}, new Set())
 			);
@@ -584,26 +673,49 @@ class Chunk {
 		return result;
 	}
 
-	getChildIdsByOrdersMap() {
+	getChildIdsByOrdersMap(includeDirectChildren) {
 		const chunkMaps = Object.create(null);
 
-		for (const chunk of this.getAllAsyncChunks()) {
+		const addChildIdsByOrdersToMap = chunk => {
 			const data = chunk.getChildIdsByOrders();
 			for (const key of Object.keys(data)) {
 				let chunkMap = chunkMaps[key];
-				if (chunkMap === undefined)
+				if (chunkMap === undefined) {
 					chunkMaps[key] = chunkMap = Object.create(null);
+				}
 				chunkMap[chunk.id] = data[key];
 			}
+		};
+
+		if (includeDirectChildren) {
+			addChildIdsByOrdersToMap(this);
 		}
+
+		for (const chunk of this.getAllAsyncChunks()) {
+			addChildIdsByOrdersToMap(chunk);
+		}
+
 		return chunkMaps;
 	}
 
+	/**
+	 * @typedef {Object} ChunkModuleMaps
+	 * @property {Record<string|number, (string|number)[]>} id
+	 * @property {Record<string|number, string>} hash
+	 */
+
+	/**
+	 * @param {ModuleFilterPredicate} filterFn function used to filter modules
+	 * @returns {ChunkModuleMaps} module map information
+	 */
 	getChunkModuleMaps(filterFn) {
+		/** @type {Record<string|number, (string|number)[]>} */
 		const chunkModuleIdMap = Object.create(null);
+		/** @type {Record<string|number, string>} */
 		const chunkModuleHashMap = Object.create(null);
 
 		for (const chunk of this.getAllAsyncChunks()) {
+			/** @type {(string|number)[]} */
 			let array;
 			for (const module of chunk.modulesIterable) {
 				if (filterFn(module)) {
@@ -628,8 +740,8 @@ class Chunk {
 
 	/**
 	 *
-	 * @param {ModuleFilterPredicate} filterFn predicate function used to filter modules
-	 * @param {ChunkFilterPredicate} filterChunkFn predicate function used to filter chunks
+	 * @param {function(Module): boolean} filterFn predicate function used to filter modules
+	 * @param {function(Chunk): boolean} filterChunkFn predicate function used to filter chunks
 	 * @returns {boolean} return true if module exists in graph
 	 */
 	hasModuleInGraph(filterFn, filterChunkFn) {
@@ -641,12 +753,17 @@ class Chunk {
 				if (!chunksProcessed.has(chunk)) {
 					chunksProcessed.add(chunk);
 					if (!filterChunkFn || filterChunkFn(chunk)) {
-						for (const module of chunk.modulesIterable)
-							if (filterFn(module)) return true;
+						for (const module of chunk.modulesIterable) {
+							if (filterFn(module)) {
+								return true;
+							}
+						}
 					}
 				}
 			}
-			for (const child of chunkGroup.childrenIterable) queue.add(child);
+			for (const child of chunkGroup.childrenIterable) {
+				queue.add(child);
+			}
 		}
 		return false;
 	}
@@ -659,17 +776,37 @@ class Chunk {
 // TODO remove in webpack 5
 Object.defineProperty(Chunk.prototype, "forEachModule", {
 	configurable: false,
-	value: util.deprecate(function(fn) {
-		this._modules.forEach(fn);
-	}, "Chunk.forEachModule: Use for(const module of chunk.modulesIterable) instead")
+	value: util.deprecate(
+		/**
+		 * @deprecated
+		 * @this {Chunk}
+		 * @typedef {function(any, any, Set<any>): void} ForEachModuleCallback
+		 * @param {ForEachModuleCallback} fn Callback function
+		 * @returns {void}
+		 */
+		function(fn) {
+			this._modules.forEach(fn);
+		},
+		"Chunk.forEachModule: Use for(const module of chunk.modulesIterable) instead"
+	)
 });
 
 // TODO remove in webpack 5
 Object.defineProperty(Chunk.prototype, "mapModules", {
 	configurable: false,
-	value: util.deprecate(function(fn) {
-		return Array.from(this._modules, fn);
-	}, "Chunk.mapModules: Use Array.from(chunk.modulesIterable, fn) instead")
+	value: util.deprecate(
+		/**
+		 * @deprecated
+		 * @this {Chunk}
+		 * @typedef {function(any, number): any} MapModulesCallback
+		 * @param {MapModulesCallback} fn Callback function
+		 * @returns {TODO[]} result of mapped modules
+		 */
+		function(fn) {
+			return Array.from(this._modules, fn);
+		},
+		"Chunk.mapModules: Use Array.from(chunk.modulesIterable, fn) instead"
+	)
 });
 
 // TODO remove in webpack 5
