@@ -6,7 +6,7 @@
 
 const ChunkGroup = require("./ChunkGroup");
 
-/** @typedef {import("./Chunk.js")} Chunk */
+/** @typedef {import("./Chunk")} Chunk */
 
 /**
  * Entrypoint serves as an encapsulation primitive for chunks that are
@@ -27,7 +27,7 @@ class Entrypoint extends ChunkGroup {
 
 	/**
 	 * isInitial will always return true for Entrypoint ChunkGroup.
-	 * @return {true} returns true as all entrypoints are initial ChunkGroups
+	 * @returns {true} returns true as all entrypoints are initial ChunkGroups
 	 */
 	isInitial() {
 		return true;
@@ -36,7 +36,7 @@ class Entrypoint extends ChunkGroup {
 	/**
 	 * Sets the runtimeChunk for an entrypoint.
 	 * @param {Chunk} chunk the chunk being set as the runtime chunk.
-	 * @return {void}
+	 * @returns {void}
 	 */
 	setRuntimeChunk(chunk) {
 		this.runtimeChunk = chunk;
@@ -44,11 +44,21 @@ class Entrypoint extends ChunkGroup {
 
 	/**
 	 * Fetches the chunk reference containing the webpack bootstrap code
-	 * @return {Chunk} returns the runtime chunk or first chunk in `this.chunks`
+	 * @returns {Chunk} returns the runtime chunk or first chunk in `this.chunks`
 	 */
 	getRuntimeChunk() {
 		return this.runtimeChunk || this.chunks[0];
 	}
+
+	/**
+	 * @param {Chunk} oldChunk chunk to be replaced
+	 * @param {Chunk} newChunk New chunkt that will be replaced
+	 * @returns {boolean} rerturns true for
+	 */
+	replaceChunk(oldChunk, newChunk) {
+		if (this.runtimeChunk === oldChunk) this.runtimeChunk = newChunk;
+		return super.replaceChunk(oldChunk, newChunk);
+	}
 }
 
 module.exports = Entrypoint;
