@@ -10,8 +10,11 @@ const webpackOptionsFlag = "WEBPACK_OPTIONS";
 
 exports.cutOffByFlag = (stack, flag) => {
 	stack = stack.split("\n");
-	for (let i = 0; i < stack.length; i++)
-		if (stack[i].includes(flag)) stack.length = i;
+	for (let i = 0; i < stack.length; i++) {
+		if (stack[i].includes(flag)) {
+			stack.length = i;
+		}
+	}
 	return stack.join("\n");
 };
 
