@@ -48,8 +48,9 @@ const getHash = str => {
 };
 
 const asRegExp = test => {
-	if (typeof test === "string")
+	if (typeof test === "string") {
 		test = new RegExp("^" + test.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&"));
+	}
 	return test;
 };
 
@@ -141,7 +142,9 @@ ModuleFilenameHelpers.replaceDuplicates = (array, fn, comparator) => {
 		if (countMap[item].length > 1) {
 			if (comparator && countMap[item][0] === i) return item;
 			return fn(item, i, posMap[item]++);
-		} else return item;
+		} else {
+			return item;
+		}
 	});
 };
 
@@ -156,11 +159,20 @@ ModuleFilenameHelpers.matchPart = (str, test) => {
 };
 
 ModuleFilenameHelpers.matchObject = (obj, str) => {
-	if (obj.test)
-		if (!ModuleFilenameHelpers.matchPart(str, obj.test)) return false;
-	if (obj.include)
-		if (!ModuleFilenameHelpers.matchPart(str, obj.include)) return false;
-	if (obj.exclude)
-		if (ModuleFilenameHelpers.matchPart(str, obj.exclude)) return false;
+	if (obj.test) {
+		if (!ModuleFilenameHelpers.matchPart(str, obj.test)) {
+			return false;
+		}
+	}
+	if (obj.include) {
+		if (!ModuleFilenameHelpers.matchPart(str, obj.include)) {
+			return false;
+		}
+	}
+	if (obj.exclude) {
+		if (ModuleFilenameHelpers.matchPart(str, obj.exclude)) {
+			return false;
+		}
+	}
 	return true;
 };
