@@ -4,8 +4,15 @@
 */
 "use strict";
 
+const validateOptions = require("schema-utils");
+const schema = require("../schemas/plugins/ProgressPlugin.json");
+
+/** @typedef {import("../declarations/plugins/ProgressPlugin").ProgressPluginArgument} ProgressPluginArgument */
+/** @typedef {import("../declarations/plugins/ProgressPlugin").ProgressPluginOptions} ProgressPluginOptions */
+
 const createDefaultHandler = profile => {
 	let lineCaretPosition = 0;
+	let lastMessage = "";
 	let lastState;
 	let lastStateTime;
 
@@ -24,7 +31,7 @@ const createDefaultHandler = profile => {
 			for (let detail of details) {
 				if (!detail) continue;
 				if (detail.length > 40) {
-					detail = `…${detail.substr(detail.length - 39)}`;
+					detail = `...${detail.substr(detail.length - 39)}`;
 				}
 				msg += ` ${detail}`;
 			}
@@ -46,8 +53,11 @@ const createDefaultHandler = profile => {
 				lastStateTime = now;
 			}
 		}
-		goToLineStart(msg);
-		process.stderr.write(msg);
+		if (lastMessage !== msg) {
+			goToLineStart(msg);
+			process.stderr.write(msg);
+			lastMessage = msg;
+		}
 	};
 
 	const goToLineStart = nextMessage => {
@@ -66,24 +76,39 @@ const createDefaultHandler = profile => {
 };
 
 class ProgressPlugin {
+	/**
+	 * @param {ProgressPluginArgument} options options
+	 */
 	constructor(options) {
 		if (typeof options === "function") {
 			options = {
 				handler: options
 			};
 		}
+
 		options = options || {};
+		validateOptions(schema, options, "Progress Plugin");
+		options = Object.assign({}, ProgressPlugin.defaultOptions, options);
+
 		this.profile = options.profile;
 		this.handler = options.handler;
+		this.modulesCount = options.modulesCount;
+		this.showEntries = options.entries;
+		this.showModules = options.modules;
+		this.showActiveModules = options.activeModules;
 	}
 
 	apply(compiler) {
+		const { modulesCount } = this;
 		const handler = this.handler || createDefaultHandler(this.profile);
+		const showEntries = this.showEntries;
+		const showModules = this.showModules;
+		const showActiveModules = this.showActiveModules;
 		if (compiler.compilers) {
 			const states = new Array(compiler.compilers.length);
 			compiler.compilers.forEach((compiler, idx) => {
 				new ProgressPlugin((p, msg, ...args) => {
-					states[idx] = args;
+					states[idx] = [p, msg, ...args];
 					handler(
 						states
 							.map(state => (state && state[0]) || 0)
@@ -95,48 +120,97 @@ class ProgressPlugin {
 			});
 		} else {
 			let lastModulesCount = 0;
-			let moduleCount = 500;
+			let lastEntriesCount = 0;
+			let moduleCount = modulesCount;
+			let entriesCount = 1;
 			let doneModules = 0;
-			const activeModules = [];
+			let doneEntries = 0;
+			const activeModules = new Set();
+			let lastActiveModule = "";
 
-			const update = module => {
-				handler(
-					0.1 + doneModules / Math.max(lastModulesCount, moduleCount) * 0.6,
-					"building modules",
-					`${doneModules}/${moduleCount} modules`,
-					`${activeModules.length} active`,
-					activeModules[activeModules.length - 1]
-				);
+			const update = () => {
+				const percentByModules =
+					doneModules / Math.max(lastModulesCount, moduleCount);
+				const percentByEntries =
+					doneEntries / Math.max(lastEntriesCount, entriesCount);
+
+				const items = [
+					0.1 + Math.max(percentByModules, percentByEntries) * 0.6,
+					"building"
+				];
+				if (showEntries) {
+					items.push(`${doneEntries}/${entriesCount} entries`);
+				}
+				if (showModules) {
+					items.push(`${doneModules}/${moduleCount} modules`);
+				}
+				if (showActiveModules) {
+					items.push(`${activeModules.size} active`);
+					items.push(lastActiveModule);
+				}
+				handler(...items);
+			};
+
+			const moduleAdd = module => {
+				moduleCount++;
+				if (showActiveModules) {
+					const ident = module.identifier();
+					if (ident) {
+						activeModules.add(ident);
+						lastActiveModule = ident;
+					}
+				}
+				update();
+			};
+
+			const entryAdd = (entry, name) => {
+				entriesCount++;
+				update();
 			};
 
 			const moduleDone = module => {
 				doneModules++;
-				const ident = module.identifier();
-				if (ident) {
-					const idx = activeModules.indexOf(ident);
-					if (idx >= 0) activeModules.splice(idx, 1);
+				if (showActiveModules) {
+					const ident = module.identifier();
+					if (ident) {
+						activeModules.delete(ident);
+						if (lastActiveModule === ident) {
+							lastActiveModule = "";
+							for (const m of activeModules) {
+								lastActiveModule = m;
+							}
+						}
+					}
 				}
 				update();
 			};
+
+			const entryDone = (entry, name) => {
+				doneEntries++;
+				update();
+			};
+
 			compiler.hooks.compilation.tap("ProgressPlugin", compilation => {
 				if (compilation.compiler.isChild()) return;
 				lastModulesCount = moduleCount;
-				moduleCount = 0;
-				doneModules = 0;
+				lastEntriesCount = entriesCount;
+				moduleCount = entriesCount = 0;
+				doneModules = doneEntries = 0;
 				handler(0, "compiling");
-				compilation.hooks.buildModule.tap("ProgressPlugin", module => {
-					moduleCount++;
-					const ident = module.identifier();
-					if (ident) {
-						activeModules.push(ident);
-					}
-					update();
-				});
+
+				compilation.hooks.buildModule.tap("ProgressPlugin", moduleAdd);
 				compilation.hooks.failedModule.tap("ProgressPlugin", moduleDone);
 				compilation.hooks.succeedModule.tap("ProgressPlugin", moduleDone);
+
+				compilation.hooks.addEntry.tap("ProgressPlugin", entryAdd);
+				compilation.hooks.failedEntry.tap("ProgressPlugin", entryDone);
+				compilation.hooks.succeedEntry.tap("ProgressPlugin", entryDone);
+
 				const hooks = {
 					finishModules: "finish module graph",
 					seal: "sealing",
+					beforeChunks: "chunk graph",
+					afterChunks: "after chunk graph",
 					optimizeDependenciesBasic: "basic dependencies optimization",
 					optimizeDependencies: "dependencies optimization",
 					optimizeDependenciesAdvanced: "advanced dependencies optimization",
@@ -171,6 +245,7 @@ class ProgressPlugin {
 					recordModules: "record modules",
 					recordChunks: "record chunks",
 					beforeHash: "hashing",
+					contentHash: "content hashing",
 					afterHash: "after hashing",
 					recordHash: "record hash",
 					beforeModuleAssets: "module assets processing",
@@ -187,7 +262,7 @@ class ProgressPlugin {
 				const numberOfHooks = Object.keys(hooks).length;
 				Object.keys(hooks).forEach((name, idx) => {
 					const title = hooks[name];
-					const percentage = idx / numberOfHooks * 0.25 + 0.7;
+					const percentage = (idx / numberOfHooks) * 0.25 + 0.7;
 					compilation.hooks[name].intercept({
 						name: "ProgressPlugin",
 						context: true,
@@ -222,10 +297,35 @@ class ProgressPlugin {
 					handler(0.95, "emitting", tap.name);
 				}
 			});
+			compiler.hooks.afterEmit.intercept({
+				name: "ProgressPlugin",
+				context: true,
+				call: () => {
+					handler(0.98, "after emitting");
+				},
+				tap: (context, tap) => {
+					if (context) {
+						context.reportProgress = (p, ...args) => {
+							handler(0.98, "after emitting", tap.name, ...args);
+						};
+					}
+					handler(0.98, "after emitting", tap.name);
+				}
+			});
 			compiler.hooks.done.tap("ProgressPlugin", () => {
 				handler(1, "");
 			});
 		}
 	}
 }
+
+ProgressPlugin.defaultOptions = {
+	profile: false,
+	modulesCount: 500,
+	modules: true,
+	activeModules: true,
+	// TODO webpack 5 default this to true
+	entries: false
+};
+
 module.exports = ProgressPlugin;
