@@ -10,6 +10,7 @@ const PATH_CHARS_REGEXP = /[-[\]{}()*+?.,\\^$|#\s]/g;
 const SEPARATOR_REGEXP = /[/\\]$/;
 const FRONT_OR_BACK_BANG_REGEXP = /^!|!$/g;
 const INDEX_JS_REGEXP = /\/index.js(!|\?|\(query\))/g;
+const MATCH_RESOURCE_REGEXP = /!=!/;
 
 const normalizeBackSlashDirection = request => {
 	return request.replace(NORMALIZE_SLASH_DIRECTION_REGEXP, "/");
@@ -23,8 +24,9 @@ const createRegExpForPath = path => {
 class RequestShortener {
 	constructor(directory) {
 		directory = normalizeBackSlashDirection(directory);
-		if (SEPARATOR_REGEXP.test(directory))
+		if (SEPARATOR_REGEXP.test(directory)) {
 			directory = directory.substr(0, directory.length - 1);
+		}
 
 		if (directory) {
 			this.currentDirectoryRegExp = createRegExpForPath(directory);
@@ -54,18 +56,25 @@ class RequestShortener {
 	shorten(request) {
 		if (!request) return request;
 		const cacheEntry = this.cache.get(request);
-		if (cacheEntry !== undefined) return cacheEntry;
+		if (cacheEntry !== undefined) {
+			return cacheEntry;
+		}
 		let result = normalizeBackSlashDirection(request);
-		if (this.buildinsAsModule && this.buildinsRegExp)
+		if (this.buildinsAsModule && this.buildinsRegExp) {
 			result = result.replace(this.buildinsRegExp, "!(webpack)");
-		if (this.currentDirectoryRegExp)
+		}
+		if (this.currentDirectoryRegExp) {
 			result = result.replace(this.currentDirectoryRegExp, "!.");
-		if (this.parentDirectoryRegExp)
+		}
+		if (this.parentDirectoryRegExp) {
 			result = result.replace(this.parentDirectoryRegExp, "!..");
-		if (!this.buildinsAsModule && this.buildinsRegExp)
+		}
+		if (!this.buildinsAsModule && this.buildinsRegExp) {
 			result = result.replace(this.buildinsRegExp, "!(webpack)");
+		}
 		result = result.replace(INDEX_JS_REGEXP, "$1");
 		result = result.replace(FRONT_OR_BACK_BANG_REGEXP, "");
+		result = result.replace(MATCH_RESOURCE_REGEXP, " = ");
 		this.cache.set(request, result);
 		return result;
 	}
