@@ -8,11 +8,21 @@ const RequestShortener = require("./RequestShortener");
 const SizeFormatHelpers = require("./SizeFormatHelpers");
 const formatLocation = require("./formatLocation");
 const identifierUtils = require("./util/identifier");
+const compareLocations = require("./compareLocations");
 
 const optionsOrFallback = (...args) => {
 	let optionValues = [];
 	optionValues.push(...args);
-	return optionValues.find(optionValue => typeof optionValue !== "undefined");
+	return optionValues.find(optionValue => optionValue !== undefined);
+};
+
+const compareId = (a, b) => {
+	if (typeof a !== typeof b) {
+		return typeof a < typeof b ? -1 : 1;
+	}
+	if (a < b) return -1;
+	if (a > b) return 1;
+	return 0;
 };
 
 class Stats {
@@ -56,8 +66,8 @@ class Stats {
 	formatFilePath(filePath) {
 		const OPTIONS_REGEXP = /^(\s|\S)*!/;
 		return filePath.includes("!")
-			? `${filePath.replace(OPTIONS_REGEXP, "")} (${filePath})\n`
-			: `${filePath}\n`;
+			? `${filePath.replace(OPTIONS_REGEXP, "")} (${filePath})`
+			: `${filePath}`;
 	}
 
 	hasWarnings() {
@@ -98,26 +108,28 @@ class Stats {
 		}
 
 		const optionOrLocalFallback = (v, def) =>
-			typeof v !== "undefined"
-				? v
-				: typeof options.all !== "undefined"
-					? options.all
-					: def;
+			v !== undefined ? v : options.all !== undefined ? options.all : def;
 
 		const testAgainstGivenOption = item => {
 			if (typeof item === "string") {
 				const regExp = new RegExp(
 					`[\\\\/]${item.replace(
+						// eslint-disable-next-line no-useless-escape
 						/[-[\]{}()*+?.\\^$|]/g,
 						"\\$&"
 					)}([\\\\/]|$|!|\\?)`
-				); // eslint-disable-line no-useless-escape
+				);
 				return ident => regExp.test(ident);
 			}
-			if (item && typeof item === "object" && typeof item.test === "function")
+			if (item && typeof item === "object" && typeof item.test === "function") {
 				return ident => item.test(ident);
-			if (typeof item === "function") return item;
-			if (typeof item === "boolean") return () => item;
+			}
+			if (typeof item === "function") {
+				return item;
+			}
+			if (typeof item === "boolean") {
+				return () => item;
+			}
 		};
 
 		const compilation = this.compilation;
@@ -238,39 +250,46 @@ class Stats {
 			if (a[fieldKey] === null) return 1;
 			if (b[fieldKey] === null) return -1;
 			if (a[fieldKey] === b[fieldKey]) return 0;
+			if (typeof a[fieldKey] !== typeof b[fieldKey])
+				return typeof a[fieldKey] < typeof b[fieldKey] ? -1 : 1;
 			return a[fieldKey] < b[fieldKey] ? -1 : 1;
 		};
 
-		const sortByField = field => (a, b) => {
-			if (!field) {
-				return 0;
-			}
+		const sortByField = (field, originalArray) => {
+			const originalMap = originalArray.reduce((map, v, i) => {
+				map.set(v, i);
+				return map;
+			}, new Map());
+			return (a, b) => {
+				if (field) {
+					const fieldKey = this.normalizeFieldKey(field);
 
-			const fieldKey = this.normalizeFieldKey(field);
+					// if a field is prefixed with a "!" the sort is reversed!
+					const sortIsRegular = this.sortOrderRegular(field);
 
-			// if a field is prefixed with a "!" the sort is reversed!
-			const sortIsRegular = this.sortOrderRegular(field);
-
-			return sortByFieldAndOrder(
-				fieldKey,
-				sortIsRegular ? a : b,
-				sortIsRegular ? b : a
-			);
+					const cmp = sortByFieldAndOrder(
+						fieldKey,
+						sortIsRegular ? a : b,
+						sortIsRegular ? b : a
+					);
+					if (cmp) return cmp;
+				}
+				return originalMap.get(a) - originalMap.get(b);
+			};
 		};
 
 		const formatError = e => {
 			let text = "";
-			if (typeof e === "string")
-				e = {
-					message: e
-				};
+			if (typeof e === "string") {
+				e = { message: e };
+			}
 			if (e.chunk) {
 				text += `chunk ${e.chunk.name || e.chunk.id}${
 					e.chunk.hasRuntime()
 						? " [entry]"
 						: e.chunk.canBeInitial()
-							? " [initial]"
-							: ""
+						? " [initial]"
+						: ""
 				}\n`;
 			}
 			if (e.file) {
@@ -284,13 +303,23 @@ class Stats {
 				text += this.formatFilePath(
 					e.module.readableIdentifier(requestShortener)
 				);
+				if (typeof e.loc === "object") {
+					const locInfo = formatLocation(e.loc);
+					if (locInfo) text += ` ${locInfo}`;
+				}
+				text += "\n";
 			}
 			text += e.message;
-			if (showErrorDetails && e.details) text += `\n${e.details}`;
-			if (showErrorDetails && e.missing)
+			if (showErrorDetails && e.details) {
+				text += `\n${e.details}`;
+			}
+			if (showErrorDetails && e.missing) {
 				text += e.missing.map(item => `\n[${item}]`).join("");
+			}
 			if (showModuleTrace && e.origin) {
-				text += `\n @ ${e.origin.readableIdentifier(requestShortener)}`;
+				text += `\n @ ${this.formatFilePath(
+					e.origin.readableIdentifier(requestShortener)
+				)}`;
 				if (typeof e.originLoc === "object") {
 					const locInfo = formatLocation(e.originLoc);
 					if (locInfo) text += ` ${locInfo}`;
@@ -362,7 +391,7 @@ class Stats {
 		}
 		if (showAssets) {
 			const assetsByFile = {};
-			const compilationAssets = Object.keys(compilation.assets);
+			const compilationAssets = Object.keys(compilation.assets).sort();
 			obj.assetsByChunkName = {};
 			obj.assets = compilationAssets
 				.map(asset => {
@@ -371,7 +400,10 @@ class Stats {
 						size: compilation.assets[asset].size(),
 						chunks: [],
 						chunkNames: [],
-						emitted: compilation.assets[asset].emitted
+						// TODO webpack 5: remove .emitted
+						emitted:
+							compilation.assets[asset].emitted ||
+							compilation.emittedAssets.has(asset)
 					};
 
 					if (showPerformance) {
@@ -392,16 +424,18 @@ class Stats {
 						}
 						if (chunk.name) {
 							assetsByFile[asset].chunkNames.push(chunk.name);
-							if (obj.assetsByChunkName[chunk.name])
+							if (obj.assetsByChunkName[chunk.name]) {
 								obj.assetsByChunkName[chunk.name] = []
 									.concat(obj.assetsByChunkName[chunk.name])
 									.concat([asset]);
-							else obj.assetsByChunkName[chunk.name] = asset;
+							} else {
+								obj.assetsByChunkName[chunk.name] = asset;
+							}
 						}
 					}
 				}
 			}
-			obj.assets.sort(sortByField(sortAssets));
+			obj.assets.sort(sortByField(sortAssets, obj.assets));
 		}
 
 		const fnChunkGroup = groupMap => {
@@ -500,6 +534,23 @@ class Stats {
 			}
 			if (showReasons) {
 				obj.reasons = module.reasons
+					.sort((a, b) => {
+						if (a.module && !b.module) return -1;
+						if (!a.module && b.module) return 1;
+						if (a.module && b.module) {
+							const cmp = compareId(a.module.id, b.module.id);
+							if (cmp) return cmp;
+						}
+						if (a.dependency && !b.dependency) return -1;
+						if (!a.dependency && b.dependency) return 1;
+						if (a.dependency && b.dependency) {
+							const cmp = compareLocations(a.dependency.loc, b.dependency.loc);
+							if (cmp) return cmp;
+							if (a.dependency.type < b.dependency.type) return -1;
+							if (a.dependency.type > b.dependency.type) return 1;
+						}
+						return 0;
+					})
 					.map(reason => {
 						const obj = {
 							moduleId: reason.module ? reason.module.id : null,
@@ -513,21 +564,26 @@ class Stats {
 								? reason.module.readableIdentifier(requestShortener)
 								: null,
 							type: reason.dependency ? reason.dependency.type : null,
+							explanation: reason.explanation,
 							userRequest: reason.dependency
 								? reason.dependency.userRequest
 								: null
 						};
 						if (reason.dependency) {
 							const locInfo = formatLocation(reason.dependency.loc);
-							if (locInfo) obj.loc = locInfo;
+							if (locInfo) {
+								obj.loc = locInfo;
+							}
 						}
 						return obj;
-					})
-					.sort((a, b) => a.moduleId - b.moduleId);
+					});
 			}
 			if (showUsedExports) {
-				if (module.used === true) obj.usedExports = module.usedExports;
-				else if (module.used === false) obj.usedExports = false;
+				if (module.used === true) {
+					obj.usedExports = module.usedExports;
+				} else if (module.used === false) {
+					obj.usedExports = false;
+				}
 			}
 			if (showProvidedExports) {
 				obj.providedExports = Array.isArray(module.buildMeta.providedExports)
@@ -547,11 +603,11 @@ class Stats {
 				if (module.modules) {
 					const modules = module.modules;
 					obj.modules = modules
-						.sort(sortByField("depth"))
+						.sort(sortByField("depth", modules))
 						.filter(createModuleFilter())
 						.map(fnModule);
 					obj.filteredModules = modules.length - obj.modules.length;
-					obj.modules.sort(sortByField(sortModules));
+					obj.modules.sort(sortByField(sortModules, obj.modules));
 				}
 			}
 			if (showSource && module._source) {
@@ -591,19 +647,20 @@ class Stats {
 					names: chunk.name ? [chunk.name] : [],
 					files: chunk.files.slice(),
 					hash: chunk.renderedHash,
-					siblings: Array.from(siblings).sort(),
-					parents: Array.from(parents).sort(),
-					children: Array.from(children).sort(),
+					siblings: Array.from(siblings).sort(compareId),
+					parents: Array.from(parents).sort(compareId),
+					children: Array.from(children).sort(compareId),
 					childrenByOrder: childIdByOrder
 				};
 				if (showChunkModules) {
-					obj.modules = chunk
-						.getModules()
-						.sort(sortByField("depth"))
+					const modules = chunk.getModules();
+					obj.modules = modules
+						.slice()
+						.sort(sortByField("depth", modules))
 						.filter(createModuleFilter())
 						.map(fnModule);
 					obj.filteredModules = chunk.getNumberOfModules() - obj.modules.length;
-					obj.modules.sort(sortByField(sortModules));
+					obj.modules.sort(sortByField(sortModules, obj.modules));
 				}
 				if (showChunkOrigins) {
 					obj.origins = Array.from(chunk.groupsIterable, g => g.origins)
@@ -620,40 +677,27 @@ class Stats {
 							reasons: origin.reasons || []
 						}))
 						.sort((a, b) => {
-							if (
-								typeof a.moduleId === "number" &&
-								typeof b.moduleId !== "number"
-							)
-								return 1;
-							if (
-								typeof a.moduleId !== "number" &&
-								typeof b.moduleId === "number"
-							)
-								return -1;
-							if (
-								typeof a.moduleId === "number" &&
-								typeof b.moduleId === "number"
-							) {
-								const diffId = a.moduleId - b.moduleId;
-								if (diffId !== 0) return diffId;
-							}
-							if (a.loc < b.loc) return -1;
-							if (a.loc > b.loc) return 1;
+							const cmp1 = compareId(a.moduleId, b.moduleId);
+							if (cmp1) return cmp1;
+							const cmp2 = compareId(a.loc, b.loc);
+							if (cmp2) return cmp2;
+							const cmp3 = compareId(a.request, b.request);
+							if (cmp3) return cmp3;
 							return 0;
 						});
 				}
 				return obj;
 			});
-			obj.chunks.sort(sortByField(sortChunks));
+			obj.chunks.sort(sortByField(sortChunks, obj.chunks));
 		}
 		if (showModules) {
 			obj.modules = compilation.modules
 				.slice()
-				.sort(sortByField("depth"))
+				.sort(sortByField("depth", compilation.modules))
 				.filter(createModuleFilter())
 				.map(fnModule);
 			obj.filteredModules = compilation.modules.length - obj.modules.length;
-			obj.modules.sort(sortByField(sortModules));
+			obj.modules.sort(sortByField(sortModules, obj.modules));
 		}
 		if (showChildren) {
 			obj.children = compilation.children.map((child, idx) => {
@@ -661,12 +705,13 @@ class Stats {
 				const obj = new Stats(child).toJson(childOptions, forToString);
 				delete obj.hash;
 				delete obj.version;
-				if (child.name)
+				if (child.name) {
 					obj.name = identifierUtils.makePathsRelative(
 						context,
 						child.name,
 						compilation.cache
 					);
+				}
 				return obj;
 			});
 		}
@@ -744,7 +789,9 @@ class Stats {
 			const rows = array.length;
 			const cols = array[0].length;
 			const colSizes = new Array(cols);
-			for (let col = 0; col < cols; col++) colSizes[col] = 0;
+			for (let col = 0; col < cols; col++) {
+				colSizes[col] = 0;
+			}
 			for (let row = 0; row < rows; row++) {
 				for (let col = 0; col < cols; col++) {
 					const value = `${getText(array, row, col)}`;
@@ -758,11 +805,18 @@ class Stats {
 					const format = array[row][col].color;
 					const value = `${getText(array, row, col)}`;
 					let l = value.length;
-					if (align[col] === "l") format(value);
-					for (; l < colSizes[col] && col !== cols - 1; l++) colors.normal(" ");
-					if (align[col] === "r") format(value);
-					if (col + 1 < cols && colSizes[col] !== 0)
+					if (align[col] === "l") {
+						format(value);
+					}
+					for (; l < colSizes[col] && col !== cols - 1; l++) {
+						colors.normal(" ");
+					}
+					if (align[col] === "r") {
+						format(value);
+					}
+					if (col + 1 < cols && colSizes[col] !== 0) {
 						colors.normal(splitter || "  ");
+					}
 				}
 				newline();
 			}
@@ -980,21 +1034,26 @@ class Stats {
 				colors.magenta(" [prefetched]");
 			}
 			if (module.failed) colors.red(" [failed]");
-			if (module.warnings)
+			if (module.warnings) {
 				colors.yellow(
 					` [${module.warnings} warning${module.warnings === 1 ? "" : "s"}]`
 				);
-			if (module.errors)
+			}
+			if (module.errors) {
 				colors.red(
 					` [${module.errors} error${module.errors === 1 ? "" : "s"}]`
 				);
+			}
 		};
 
 		const processModuleContent = (module, prefix) => {
 			if (Array.isArray(module.providedExports)) {
 				colors.normal(prefix);
-				if (module.providedExports.length === 0) colors.cyan("[no exports]");
-				else colors.cyan(`[exports: ${module.providedExports.join(", ")}]`);
+				if (module.providedExports.length === 0) {
+					colors.cyan("[no exports]");
+				} else {
+					colors.cyan(`[exports: ${module.providedExports.join(", ")}]`);
+				}
 				newline();
 			}
 			if (module.usedExports !== undefined) {
@@ -1058,6 +1117,10 @@ class Stats {
 						colors.normal(" ");
 						colors.normal(reason.loc);
 					}
+					if (reason.explanation) {
+						colors.normal(" ");
+						colors.cyan(reason.explanation);
+					}
 					newline();
 				}
 			}
@@ -1280,7 +1343,9 @@ class Stats {
 			);
 		}
 
-		while (buf[buf.length - 1] === "\n") buf.pop();
+		while (buf[buf.length - 1] === "\n") {
+			buf.pop();
+		}
 		return buf.join("");
 	}
 
@@ -1351,13 +1416,18 @@ class Stats {
 	static getChildOptions(options, idx) {
 		let innerOptions;
 		if (Array.isArray(options.children)) {
-			if (idx < options.children.length) innerOptions = options.children[idx];
+			if (idx < options.children.length) {
+				innerOptions = options.children[idx];
+			}
 		} else if (typeof options.children === "object" && options.children) {
 			innerOptions = options.children;
 		}
-		if (typeof innerOptions === "boolean" || typeof innerOptions === "string")
+		if (typeof innerOptions === "boolean" || typeof innerOptions === "string") {
 			innerOptions = Stats.presetToOptions(innerOptions);
-		if (!innerOptions) return options;
+		}
+		if (!innerOptions) {
+			return options;
+		}
 		const childOptions = Object.assign({}, options);
 		delete childOptions.children; // do not inherit children
 		return Object.assign(childOptions, innerOptions);
