@@ -39,10 +39,11 @@ const getReplacer = (value, allowEmpty) => {
 		// last argument in replacer is the entire input string
 		const input = args[args.length - 1];
 		if (value === null || value === undefined) {
-			if (!allowEmpty)
+			if (!allowEmpty) {
 				throw new Error(
 					`Path variable ${match} not implemented in this context: ${input}`
 				);
+			}
 			return "";
 		} else {
 			return `${value}`;
@@ -150,8 +151,9 @@ class TemplatedPathPlugin {
 					const outputOptions = mainTemplate.outputOptions;
 					const chunkFilename =
 						outputOptions.chunkFilename || outputOptions.filename;
-					if (REGEXP_CHUNKHASH_FOR_TEST.test(chunkFilename))
+					if (REGEXP_CHUNKHASH_FOR_TEST.test(chunkFilename)) {
 						hash.update(JSON.stringify(chunk.getChunkMaps(true).hash));
+					}
 					if (REGEXP_CONTENTHASH_FOR_TEST.test(chunkFilename)) {
 						hash.update(
 							JSON.stringify(
@@ -159,8 +161,9 @@ class TemplatedPathPlugin {
 							)
 						);
 					}
-					if (REGEXP_NAME_FOR_TEST.test(chunkFilename))
+					if (REGEXP_NAME_FOR_TEST.test(chunkFilename)) {
 						hash.update(JSON.stringify(chunk.getChunkMaps(true).name));
+					}
 				}
 			);
 		});
