@@ -17,16 +17,24 @@ const isWebLikeTarget = options => {
 	return options.target === "web" || options.target === "webworker";
 };
 
+const getDevtoolNamespace = library => {
+	// if options.output.library is a string
+	if (Array.isArray(library)) {
+		return library.join(".");
+	} else if (typeof library === "object") {
+		return getDevtoolNamespace(library.root);
+	}
+	return library || "";
+};
+
 class WebpackOptionsDefaulter extends OptionsDefaulter {
 	constructor() {
 		super();
 
 		this.set("entry", "./src");
 
-		this.set(
-			"devtool",
-			"make",
-			options => (options.mode === "development" ? "eval" : false)
+		this.set("devtool", "make", options =>
+			options.mode === "development" ? "eval" : false
 		);
 		this.set("cache", "make", options => options.mode === "development");
 
@@ -136,11 +144,7 @@ class WebpackOptionsDefaulter extends OptionsDefaulter {
 			}
 		});
 		this.set("output.devtoolNamespace", "make", options => {
-			if (Array.isArray(options.output.library))
-				return options.output.library.join(".");
-			else if (typeof options.output.library === "object")
-				return options.output.library.root || "";
-			return options.output.library || "";
+			return getDevtoolNamespace(options.output.library);
 		});
 		this.set("output.libraryTarget", "var");
 		this.set("output.path", path.join(process.cwd(), "dist"));
@@ -187,10 +191,8 @@ class WebpackOptionsDefaulter extends OptionsDefaulter {
 		});
 		this.set("performance.maxAssetSize", 250000);
 		this.set("performance.maxEntrypointSize", 250000);
-		this.set(
-			"performance.hints",
-			"make",
-			options => (isProductionLikeMode(options) ? "warning" : false)
+		this.set("performance.hints", "make", options =>
+			isProductionLikeMode(options) ? "warning" : false
 		);
 
 		this.set("optimization", "call", value => Object.assign({}, value));
@@ -200,6 +202,9 @@ class WebpackOptionsDefaulter extends OptionsDefaulter {
 		this.set("optimization.flagIncludedChunks", "make", options =>
 			isProductionLikeMode(options)
 		);
+		// TODO webpack 5 add `moduleIds: "named"` default for development
+		// TODO webpack 5 add `moduleIds: "size"` default for production
+		// TODO webpack 5 remove optimization.occurrenceOrder
 		this.set("optimization.occurrenceOrder", "make", options =>
 			isProductionLikeMode(options)
 		);
@@ -214,6 +219,9 @@ class WebpackOptionsDefaulter extends OptionsDefaulter {
 			isProductionLikeMode(options)
 		);
 		this.set("optimization.splitChunks", {});
+		this.set("optimization.splitChunks.hidePathInfo", "make", options => {
+			return isProductionLikeMode(options);
+		});
 		this.set("optimization.splitChunks.chunks", "async");
 		this.set("optimization.splitChunks.minSize", "make", options => {
 			return isProductionLikeMode(options) ? 30000 : 10000;
@@ -229,11 +237,13 @@ class WebpackOptionsDefaulter extends OptionsDefaulter {
 		this.set("optimization.splitChunks.name", true);
 		this.set("optimization.splitChunks.cacheGroups", {});
 		this.set("optimization.splitChunks.cacheGroups.default", {
+			automaticNamePrefix: "",
 			reuseExistingChunk: true,
 			minChunks: 2,
 			priority: -20
 		});
 		this.set("optimization.splitChunks.cacheGroups.vendors", {
+			automaticNamePrefix: "vendors",
 			test: /[\\/]node_modules[\\/]/,
 			priority: -10
 		});
@@ -253,11 +263,20 @@ class WebpackOptionsDefaulter extends OptionsDefaulter {
 		this.set("optimization.noEmitOnErrors", "make", options =>
 			isProductionLikeMode(options)
 		);
+		this.set("optimization.checkWasmTypes", "make", options =>
+			isProductionLikeMode(options)
+		);
+		this.set("optimization.mangleWasmImports", false);
+		// TODO webpack 5 remove optimization.namedModules
 		this.set(
 			"optimization.namedModules",
 			"make",
 			options => options.mode === "development"
 		);
+		this.set("optimization.hashedModuleIds", false);
+		// TODO webpack 5 add `chunkIds: "named"` default for development
+		// TODO webpack 5 add `chunkIds: "size"` default for production
+		// TODO webpack 5 remove optimization.namedChunks
 		this.set(
 			"optimization.namedChunks",
 			"make",
@@ -279,10 +298,10 @@ class WebpackOptionsDefaulter extends OptionsDefaulter {
 		this.set("optimization.minimizer", "make", options => [
 			{
 				apply: compiler => {
-					// Lazy load the uglifyjs plugin
-					const UglifyJsPlugin = require("uglifyjs-webpack-plugin");
+					// Lazy load the Terser plugin
+					const TerserPlugin = require("terser-webpack-plugin");
 					const SourceMapDevToolPlugin = require("./SourceMapDevToolPlugin");
-					new UglifyJsPlugin({
+					new TerserPlugin({
 						cache: true,
 						parallel: true,
 						sourceMap:
@@ -293,11 +312,10 @@ class WebpackOptionsDefaulter extends OptionsDefaulter {
 				}
 			}
 		]);
-		this.set(
-			"optimization.nodeEnv",
-			"make",
-			options => options.mode || "production"
-		);
+		this.set("optimization.nodeEnv", "make", options => {
+			// TODO: In webpack 5, it should return `false` when mode is `none`
+			return options.mode || "production";
+		});
 
 		this.set("resolve", "call", value => Object.assign({}, value));
 		this.set("resolve.unsafeCache", true);
@@ -305,9 +323,15 @@ class WebpackOptionsDefaulter extends OptionsDefaulter {
 		this.set("resolve.extensions", [".wasm", ".mjs", ".js", ".json"]);
 		this.set("resolve.mainFiles", ["index"]);
 		this.set("resolve.aliasFields", "make", options => {
-			if (options.target === "web" || options.target === "webworker")
+			if (
+				options.target === "web" ||
+				options.target === "webworker" ||
+				options.target === "electron-renderer"
+			) {
 				return ["browser"];
-			else return [];
+			} else {
+				return [];
+			}
 		});
 		this.set("resolve.mainFields", "make", options => {
 			if (
