@@ -30,15 +30,23 @@ const getSchemaPartText = (schemaPart, additionalPath) => {
 			if (inner) schemaPart = inner;
 		}
 	}
-	while (schemaPart.$ref) schemaPart = getSchemaPart(schemaPart.$ref);
+	while (schemaPart.$ref) {
+		schemaPart = getSchemaPart(schemaPart.$ref);
+	}
 	let schemaText = WebpackOptionsValidationError.formatSchema(schemaPart);
-	if (schemaPart.description) schemaText += `\n-> ${schemaPart.description}`;
+	if (schemaPart.description) {
+		schemaText += `\n-> ${schemaPart.description}`;
+	}
 	return schemaText;
 };
 
 const getSchemaPartDescription = schemaPart => {
-	while (schemaPart.$ref) schemaPart = getSchemaPart(schemaPart.$ref);
-	if (schemaPart.description) return `\n-> ${schemaPart.description}`;
+	while (schemaPart.$ref) {
+		schemaPart = getSchemaPart(schemaPart.$ref);
+	}
+	if (schemaPart.description) {
+		return `\n-> ${schemaPart.description}`;
+	}
 	return "";
 };
 
@@ -61,23 +69,23 @@ const indent = (str, prefix, firstLine) => {
 
 class WebpackOptionsValidationError extends WebpackError {
 	constructor(validationErrors) {
-		super();
+		super(
+			"Invalid configuration object. " +
+				"Webpack has been initialised using a configuration object that does not match the API schema.\n" +
+				validationErrors
+					.map(
+						err =>
+							" - " +
+							indent(
+								WebpackOptionsValidationError.formatValidationError(err),
+								"   ",
+								false
+							)
+					)
+					.join("\n")
+		);
 
 		this.name = "WebpackOptionsValidationError";
-		this.message =
-			"Invalid configuration object. " +
-			"Webpack has been initialised using a configuration object that does not match the API schema.\n" +
-			validationErrors
-				.map(
-					err =>
-						" - " +
-						indent(
-							WebpackOptionsValidationError.formatValidationError(err),
-							"   ",
-							false
-						)
-				)
-				.join("\n");
 		this.validationErrors = validationErrors;
 
 		Error.captureStackTrace(this, this.constructor);
@@ -87,12 +95,15 @@ class WebpackOptionsValidationError extends WebpackError {
 		prevSchemas = prevSchemas || [];
 
 		const formatInnerSchema = (innerSchema, addSelf) => {
-			if (!addSelf)
+			if (!addSelf) {
 				return WebpackOptionsValidationError.formatSchema(
 					innerSchema,
 					prevSchemas
 				);
-			if (prevSchemas.includes(innerSchema)) return "(recursive)";
+			}
+			if (prevSchemas.includes(innerSchema)) {
+				return "(recursive)";
+			}
 			return WebpackOptionsValidationError.formatSchema(
 				innerSchema,
 				prevSchemas.concat(schema)
@@ -100,15 +111,21 @@ class WebpackOptionsValidationError extends WebpackError {
 		};
 
 		if (schema.type === "string") {
-			if (schema.minLength === 1) return "non-empty string";
-			else if (schema.minLength > 1)
+			if (schema.minLength === 1) {
+				return "non-empty string";
+			}
+			if (schema.minLength > 1) {
 				return `string (min length ${schema.minLength})`;
+			}
 			return "string";
-		} else if (schema.type === "boolean") {
+		}
+		if (schema.type === "boolean") {
 			return "boolean";
-		} else if (schema.type === "number") {
+		}
+		if (schema.type === "number") {
 			return "number";
-		} else if (schema.type === "object") {
+		}
+		if (schema.type === "object") {
 			if (schema.properties) {
 				const required = schema.required || [];
 				return `object { ${Object.keys(schema.properties)
@@ -125,7 +142,8 @@ class WebpackOptionsValidationError extends WebpackError {
 				)} }`;
 			}
 			return "object";
-		} else if (schema.type === "array") {
+		}
+		if (schema.type === "array") {
 			return `[${formatInnerSchema(schema.items)}]`;
 		}
 
@@ -135,12 +153,22 @@ class WebpackOptionsValidationError extends WebpackError {
 			case "RegExp":
 				return "RegExp";
 		}
-		if (schema.$ref) return formatInnerSchema(getSchemaPart(schema.$ref), true);
-		if (schema.allOf) return schema.allOf.map(formatInnerSchema).join(" & ");
-		if (schema.oneOf) return schema.oneOf.map(formatInnerSchema).join(" | ");
-		if (schema.anyOf) return schema.anyOf.map(formatInnerSchema).join(" | ");
-		if (schema.enum)
+
+		if (schema.$ref) {
+			return formatInnerSchema(getSchemaPart(schema.$ref), true);
+		}
+		if (schema.allOf) {
+			return schema.allOf.map(formatInnerSchema).join(" & ");
+		}
+		if (schema.oneOf) {
+			return schema.oneOf.map(formatInnerSchema).join(" | ");
+		}
+		if (schema.anyOf) {
+			return schema.anyOf.map(formatInnerSchema).join(" | ");
+		}
+		if (schema.enum) {
 			return schema.enum.map(item => JSON.stringify(item)).join(" | ");
+		}
 		return JSON.stringify(schema, null, 2);
 	}
 
@@ -283,14 +311,15 @@ class WebpackOptionsValidationError extends WebpackError {
 			err.keyword === "minItems" ||
 			err.keyword === "minProperties"
 		) {
-			if (err.params.limit === 1)
+			if (err.params.limit === 1) {
 				return `${dataPath} should not be empty.${getSchemaPartDescription(
 					err.parentSchema
 				)}`;
-			else
+			} else {
 				return `${dataPath} ${err.message}${getSchemaPartDescription(
 					err.parentSchema
 				)}`;
+			}
 		} else if (err.keyword === "absolutePath") {
 			const baseMessage = `${dataPath}: ${
 				err.message
@@ -303,7 +332,6 @@ class WebpackOptionsValidationError extends WebpackError {
 			}
 			return baseMessage;
 		} else {
-			// eslint-disable-line no-fallthrough
 			return `${dataPath} ${err.message} (${JSON.stringify(
 				err,
 				null,
