@@ -9,14 +9,27 @@ const HarmonyImportDependency = require("./HarmonyImportDependency");
 const Template = require("../Template");
 const HarmonyLinkingError = require("../HarmonyLinkingError");
 
+/** @typedef {import("../Module")} Module */
+
+/** @typedef {"missing"|"unused"|"empty-star"|"reexport-non-harmony-default"|"reexport-named-default"|"reexport-namespace-object"|"reexport-non-harmony-default-strict"|"reexport-fake-namespace-object"|"rexport-non-harmony-undefined"|"safe-reexport"|"checked-reexport"|"dynamic-reexport"} ExportModeType */
+
+/** @type {Map<string, string>} */
 const EMPTY_MAP = new Map();
 
 class ExportMode {
+	/**
+	 * @param {ExportModeType} type type of the mode
+	 */
 	constructor(type) {
+		/** @type {ExportModeType} */
 		this.type = type;
+		/** @type {string|null} */
 		this.name = null;
+		/** @type {Map<string, string>} */
 		this.map = EMPTY_MAP;
+		/** @type {Module|null} */
 		this.module = null;
+		/** @type {string|null} */
 		this.userRequest = null;
 	}
 }
@@ -51,7 +64,7 @@ class HarmonyExportImportedSpecifierDependency extends HarmonyImportDependency {
 		const name = this.name;
 		const id = this.id;
 		const used = this.originModule.isUsed(name);
-		const importedModule = this.module;
+		const importedModule = this._module;
 
 		if (!importedModule) {
 			const mode = new ExportMode("missing");
@@ -208,24 +221,40 @@ class HarmonyExportImportedSpecifierDependency extends HarmonyImportDependency {
 
 			case "reexport-non-harmony-default":
 			case "reexport-named-default":
-				return new DependencyReference(mode.module, ["default"], false);
+				return new DependencyReference(
+					mode.module,
+					["default"],
+					false,
+					this.sourceOrder
+				);
 
 			case "reexport-namespace-object":
 			case "reexport-non-harmony-default-strict":
 			case "reexport-fake-namespace-object":
 			case "rexport-non-harmony-undefined":
-				return new DependencyReference(mode.module, true, false);
+				return new DependencyReference(
+					mode.module,
+					true,
+					false,
+					this.sourceOrder
+				);
 
 			case "safe-reexport":
 			case "checked-reexport":
 				return new DependencyReference(
 					mode.module,
 					Array.from(mode.map.values()),
-					false
+					false,
+					this.sourceOrder
 				);
 
 			case "dynamic-reexport":
-				return new DependencyReference(mode.module, true, false);
+				return new DependencyReference(
+					mode.module,
+					true,
+					false,
+					this.sourceOrder
+				);
 
 			default:
 				throw new Error(`Unknown mode ${mode.type}`);
@@ -237,13 +266,15 @@ class HarmonyExportImportedSpecifierDependency extends HarmonyImportDependency {
 		const result = new Set();
 		// try to learn impossible exports from other star exports with provided exports
 		for (const otherStarExport of this.otherStarExports) {
-			const otherImportedModule = otherStarExport.module;
+			const otherImportedModule = otherStarExport._module;
 			if (
 				otherImportedModule &&
 				Array.isArray(otherImportedModule.buildMeta.providedExports)
 			) {
-				for (const exportName of otherImportedModule.buildMeta.providedExports)
+				for (const exportName of otherImportedModule.buildMeta
+					.providedExports) {
 					result.add(exportName);
+				}
 			}
 		}
 		return result;
@@ -310,7 +341,7 @@ class HarmonyExportImportedSpecifierDependency extends HarmonyImportDependency {
 	}
 
 	_getErrors() {
-		const importedModule = this.module;
+		const importedModule = this._module;
 		if (!importedModule) {
 			return;
 		}
@@ -354,7 +385,7 @@ class HarmonyExportImportedSpecifierDependency extends HarmonyImportDependency {
 
 	updateHash(hash) {
 		super.updateHash(hash);
-		const hashValue = this.getHashValue(this.module);
+		const hashValue = this.getHashValue(this._module);
 		hash.update(hashValue);
 	}
 
@@ -387,7 +418,7 @@ HarmonyExportImportedSpecifierDependency.Template = class HarmonyExportImportedS
 			const used = dep.originModule.isUsed(dep.name);
 			if (!used) return NaN;
 		} else {
-			const importedModule = dep.module;
+			const importedModule = dep._module;
 
 			const activeFromOtherStarExports = dep._discoverActiveExportsFromOtherStartExports();
 
@@ -424,7 +455,7 @@ HarmonyExportImportedSpecifierDependency.Template = class HarmonyExportImportedS
 	getContent(dep) {
 		const mode = dep.getMode(false);
 		const module = dep.originModule;
-		const importedModule = dep.module;
+		const importedModule = dep._module;
 		const importVar = dep.getImportVar();
 
 		switch (mode.type) {
@@ -550,12 +581,14 @@ HarmonyExportImportedSpecifierDependency.Template = class HarmonyExportImportedS
 
 				// Filter out exports which are defined by other exports
 				// and filter out default export because it cannot be reexported with *
-				if (activeExports.size > 0)
+				if (activeExports.size > 0) {
 					content +=
 						"if(" +
 						JSON.stringify(Array.from(activeExports).concat("default")) +
 						".indexOf(__WEBPACK_IMPORT_KEY__) < 0) ";
-				else content += "if(__WEBPACK_IMPORT_KEY__ !== 'default') ";
+				} else {
+					content += "if(__WEBPACK_IMPORT_KEY__ !== 'default') ";
+				}
 				const exportsName = dep.originModule.exportsArgument;
 				return (
 					content +
@@ -570,34 +603,43 @@ HarmonyExportImportedSpecifierDependency.Template = class HarmonyExportImportedS
 
 	getReexportStatement(module, key, name, valueKey) {
 		const exportsName = module.exportsArgument;
-		const returnValue = this.getReturnValue(valueKey);
+		const returnValue = this.getReturnValue(name, valueKey);
 		return `__webpack_require__.d(${exportsName}, ${JSON.stringify(
 			key
-		)}, function() { return ${name}${returnValue}; });\n`;
+		)}, function() { return ${returnValue}; });\n`;
 	}
 
 	getReexportFakeNamespaceObjectStatement(module, key, name) {
 		const exportsName = module.exportsArgument;
 		return `__webpack_require__.d(${exportsName}, ${JSON.stringify(
 			key
-		)}, function() { return { "default": ${name} }; });\n`;
+		)}, function() { return __webpack_require__.t(${name}); });\n`;
 	}
 
 	getConditionalReexportStatement(module, key, name, valueKey) {
+		if (valueKey === false) {
+			return "/* unused export */\n";
+		}
 		const exportsName = module.exportsArgument;
-		const returnValue = this.getReturnValue(valueKey);
+		const returnValue = this.getReturnValue(name, valueKey);
 		return `if(__webpack_require__.o(${name}, ${JSON.stringify(
 			valueKey
 		)})) __webpack_require__.d(${exportsName}, ${JSON.stringify(
 			key
-		)}, function() { return ${name}${returnValue}; });\n`;
+		)}, function() { return ${returnValue}; });\n`;
 	}
 
-	getReturnValue(valueKey) {
+	getReturnValue(name, valueKey) {
 		if (valueKey === null) {
-			return "_default.a";
+			return `${name}_default.a`;
+		}
+		if (valueKey === "") {
+			return name;
+		}
+		if (valueKey === false) {
+			return "/* unused export */ undefined";
 		}
 
-		return valueKey && "[" + JSON.stringify(valueKey) + "]";
+		return `${name}[${JSON.stringify(valueKey)}]`;
 	}
 };
