@@ -19,11 +19,15 @@ module.exports = class RuntimeChunkPlugin {
 			compilation.hooks.optimizeChunksAdvanced.tap("RuntimeChunkPlugin", () => {
 				for (const entrypoint of compilation.entrypoints.values()) {
 					const chunk = entrypoint.getRuntimeChunk();
-					if (chunk.getNumberOfModules() > 0) {
-						let name = this.options.name;
-						if (typeof name === "function") {
-							name = name(entrypoint);
-						}
+					let name = this.options.name;
+					if (typeof name === "function") {
+						name = name(entrypoint);
+					}
+					if (
+						chunk.getNumberOfModules() > 0 ||
+						!chunk.preventIntegration ||
+						chunk.name !== name
+					) {
 						const newChunk = compilation.addChunk(name);
 						newChunk.preventIntegration = true;
 						entrypoint.unshiftChunk(newChunk);
