@@ -28,28 +28,21 @@ class JsonpMainTemplatePlugin {
 			}
 			return false;
 		};
-		// TODO refactor this
-		if (!mainTemplate.hooks.jsonpScript) {
-			mainTemplate.hooks.jsonpScript = new SyncWaterfallHook([
-				"source",
-				"chunk",
-				"hash"
-			]);
-		}
-		if (!mainTemplate.hooks.linkPreload) {
-			mainTemplate.hooks.linkPreload = new SyncWaterfallHook([
-				"source",
-				"chunk",
-				"hash"
-			]);
-		}
-		if (!mainTemplate.hooks.linkPrefetch) {
-			mainTemplate.hooks.linkPrefetch = new SyncWaterfallHook([
-				"source",
-				"chunk",
-				"hash"
-			]);
-		}
+		const needPrefetchingCode = chunk => {
+			const allPrefetchChunks = chunk.getChildIdsByOrdersMap(true).prefetch;
+			return allPrefetchChunks && Object.keys(allPrefetchChunks).length;
+		};
+
+		// TODO webpack 5, no adding to .hooks, use WeakMap and static methods
+		["jsonpScript", "linkPreload", "linkPrefetch"].forEach(hook => {
+			if (!mainTemplate.hooks[hook]) {
+				mainTemplate.hooks[hook] = new SyncWaterfallHook([
+					"source",
+					"chunk",
+					"hash"
+				]);
+			}
+		});
 
 		const getScriptSrcPath = (hash, chunk, chunkIdExpression) => {
 			const chunkFilename = mainTemplate.outputOptions.chunkFilename;
@@ -66,11 +59,12 @@ class JsonpMainTemplatePlugin {
 					hashWithLength(length) {
 						const shortChunkHashMap = Object.create(null);
 						for (const chunkId of Object.keys(chunkMaps.hash)) {
-							if (typeof chunkMaps.hash[chunkId] === "string")
+							if (typeof chunkMaps.hash[chunkId] === "string") {
 								shortChunkHashMap[chunkId] = chunkMaps.hash[chunkId].substr(
 									0,
 									length
 								);
+							}
 						}
 						return `" + ${JSON.stringify(
 							shortChunkHashMap
@@ -154,27 +148,28 @@ class JsonpMainTemplatePlugin {
 
 				return Template.asString([
 					"var script = document.createElement('script');",
+					"var onScriptComplete;",
 					jsonpScriptType
 						? `script.type = ${JSON.stringify(jsonpScriptType)};`
 						: "",
 					"script.charset = 'utf-8';",
 					`script.timeout = ${chunkLoadTimeout / 1000};`,
-					crossOriginLoading
-						? `script.crossOrigin = ${JSON.stringify(crossOriginLoading)};`
-						: "",
 					`if (${mainTemplate.requireFn}.nc) {`,
 					Template.indent(
 						`script.setAttribute("nonce", ${mainTemplate.requireFn}.nc);`
 					),
 					"}",
 					"script.src = jsonpScriptSrc(chunkId);",
-					"var timeout = setTimeout(function(){",
-					Template.indent([
-						"onScriptComplete({ type: 'timeout', target: script });"
-					]),
-					`}, ${chunkLoadTimeout});`,
-					"script.onerror = script.onload = onScriptComplete;",
-					"function onScriptComplete(event) {",
+					crossOriginLoading
+						? Template.asString([
+								"if (script.src.indexOf(window.location.origin + '/') !== 0) {",
+								Template.indent(
+									`script.crossOrigin = ${JSON.stringify(crossOriginLoading)};`
+								),
+								"}"
+						  ])
+						: "",
+					"onScriptComplete = function (event) {",
 					Template.indent([
 						"// avoid mem leaks in IE.",
 						"script.onerror = script.onload = null;",
@@ -196,7 +191,13 @@ class JsonpMainTemplatePlugin {
 						]),
 						"}"
 					]),
-					"};"
+					"};",
+					"var timeout = setTimeout(function(){",
+					Template.indent([
+						"onScriptComplete({ type: 'timeout', target: script });"
+					]),
+					`}, ${chunkLoadTimeout});`,
+					"script.onerror = script.onload = onScriptComplete;"
 				]);
 			}
 		);
@@ -213,6 +214,34 @@ class JsonpMainTemplatePlugin {
 						? `link.type = ${JSON.stringify(jsonpScriptType)};`
 						: "",
 					"link.charset = 'utf-8';",
+					`if (${mainTemplate.requireFn}.nc) {`,
+					Template.indent(
+						`link.setAttribute("nonce", ${mainTemplate.requireFn}.nc);`
+					),
+					"}",
+					'link.rel = "preload";',
+					'link.as = "script";',
+					"link.href = jsonpScriptSrc(chunkId);",
+					crossOriginLoading
+						? Template.asString([
+								"if (link.href.indexOf(window.location.origin + '/') !== 0) {",
+								Template.indent(
+									`link.crossOrigin = ${JSON.stringify(crossOriginLoading)};`
+								),
+								"}"
+						  ])
+						: ""
+				]);
+			}
+		);
+		mainTemplate.hooks.linkPrefetch.tap(
+			"JsonpMainTemplatePlugin",
+			(_, chunk, hash) => {
+				const crossOriginLoading =
+					mainTemplate.outputOptions.crossOriginLoading;
+
+				return Template.asString([
+					"var link = document.createElement('link');",
 					crossOriginLoading
 						? `link.crossOrigin = ${JSON.stringify(crossOriginLoading)};`
 						: "",
@@ -221,18 +250,8 @@ class JsonpMainTemplatePlugin {
 						`link.setAttribute("nonce", ${mainTemplate.requireFn}.nc);`
 					),
 					"}",
-					'link.rel = "preload";',
-					'link.as = "script";',
-					"link.href = jsonpScriptSrc(chunkId);"
-				]);
-			}
-		);
-		mainTemplate.hooks.linkPrefetch.tap(
-			"JsonpMainTemplatePlugin",
-			(_, chunk, hash) => {
-				return Template.asString([
-					"var link = document.createElement('link');",
 					'link.rel = "prefetch";',
+					'link.as = "script";',
 					"link.href = jsonpScriptSrc(chunkId);"
 				]);
 			}
@@ -263,9 +282,8 @@ class JsonpMainTemplatePlugin {
 							"promises.push(installedChunkData[2] = promise);",
 							"",
 							"// start chunk loading",
-							"var head = document.getElementsByTagName('head')[0];",
 							mainTemplate.hooks.jsonpScript.call("", chunk, hash),
-							"head.appendChild(script);"
+							"document.head.appendChild(script);"
 						]),
 						"}"
 					]),
@@ -286,19 +304,18 @@ class JsonpMainTemplatePlugin {
 					"",
 					"// chunk preloadng for javascript",
 					"",
-					`var chunkPreloadMap = ${JSON.stringify(chunkMap, null, "\t")}`,
+					`var chunkPreloadMap = ${JSON.stringify(chunkMap, null, "\t")};`,
 					"",
 					"var chunkPreloadData = chunkPreloadMap[chunkId];",
 					"if(chunkPreloadData) {",
 					Template.indent([
-						"var head = document.getElementsByTagName('head')[0];",
 						"chunkPreloadData.forEach(function(chunkId) {",
 						Template.indent([
 							"if(installedChunks[chunkId] === undefined) {",
 							Template.indent([
 								"installedChunks[chunkId] = null;",
 								mainTemplate.hooks.linkPreload.call("", chunk, hash),
-								"head.appendChild(link);"
+								"document.head.appendChild(link);"
 							]),
 							"}"
 						]),
@@ -308,45 +325,6 @@ class JsonpMainTemplatePlugin {
 				]);
 			}
 		);
-		mainTemplate.hooks.requireEnsure.tap(
-			{
-				name: "JsonpMainTemplatePlugin prefetch",
-				stage: 20
-			},
-			(source, chunk, hash) => {
-				const chunkMap = chunk.getChildIdsByOrdersMap().prefetch;
-				if (!chunkMap || Object.keys(chunkMap).length === 0) return source;
-				return Template.asString([
-					source,
-					"",
-					"// chunk prefetching for javascript",
-					"",
-					`var chunkPrefetchMap = ${JSON.stringify(chunkMap, null, "\t")}`,
-					"",
-					"var chunkPrefetchData = chunkPrefetchMap[chunkId];",
-					"if(chunkPrefetchData) {",
-					Template.indent([
-						"Promise.all(promises).then(function() {",
-						Template.indent([
-							"var head = document.getElementsByTagName('head')[0];",
-							"chunkPrefetchData.forEach(function(chunkId) {",
-							Template.indent([
-								"if(installedChunks[chunkId] === undefined) {",
-								Template.indent([
-									"installedChunks[chunkId] = null;",
-									mainTemplate.hooks.linkPrefetch.call("", chunk, hash),
-									"head.appendChild(link);"
-								]),
-								"}"
-							]),
-							"});"
-						]),
-						"})"
-					]),
-					"}"
-				]);
-			}
-		);
 		mainTemplate.hooks.requireExtensions.tap(
 			"JsonpMainTemplatePlugin",
 			(source, chunk) => {
@@ -367,6 +345,7 @@ class JsonpMainTemplatePlugin {
 			(source, chunk, hash) => {
 				if (needChunkLoadingCode(chunk)) {
 					const withDefer = needEntryDeferringCode(chunk);
+					const withPrefetch = needPrefetchingCode(chunk);
 					return Template.asString([
 						source,
 						"",
@@ -376,6 +355,7 @@ class JsonpMainTemplatePlugin {
 							"var chunkIds = data[0];",
 							"var moreModules = data[1];",
 							withDefer ? "var executeModules = data[2];" : "",
+							withPrefetch ? "var prefetchChunks = data[3] || [];" : "",
 							'// add "moreModules" to the modules object,',
 							'// then flag all "chunkIds" as loaded and fire callback',
 							"var moduleId, chunkId, i = 0, resolves = [];",
@@ -403,6 +383,22 @@ class JsonpMainTemplatePlugin {
 							]),
 							"}",
 							"if(parentJsonpFunction) parentJsonpFunction(data);",
+							withPrefetch
+								? Template.asString([
+										"// chunk prefetching for javascript",
+										"prefetchChunks.forEach(function(chunkId) {",
+										Template.indent([
+											"if(installedChunks[chunkId] === undefined) {",
+											Template.indent([
+												"installedChunks[chunkId] = null;",
+												mainTemplate.hooks.linkPrefetch.call("", chunk, hash),
+												"document.head.appendChild(link);"
+											]),
+											"}"
+										]),
+										"});"
+								  ])
+								: "",
 							"while(resolves.length) {",
 							Template.indent("resolves.shift()();"),
 							"}",
@@ -477,6 +473,25 @@ class JsonpMainTemplatePlugin {
 				return source;
 			}
 		);
+		mainTemplate.hooks.beforeStartup.tap(
+			"JsonpMainTemplatePlugin",
+			(source, chunk, hash) => {
+				const prefetchChunks = chunk.getChildIdsByOrders().prefetch;
+				if (
+					needChunkLoadingCode(chunk) &&
+					prefetchChunks &&
+					prefetchChunks.length
+				) {
+					return Template.asString([
+						source,
+						`webpackJsonpCallback([[], {}, 0, ${JSON.stringify(
+							prefetchChunks
+						)}]);`
+					]);
+				}
+				return source;
+			}
+		);
 		mainTemplate.hooks.startup.tap(
 			"JsonpMainTemplatePlugin",
 			(source, chunk, hash) => {
@@ -538,15 +553,13 @@ class JsonpMainTemplatePlugin {
 					}
 				);
 				const runtimeSource = Template.getFunctionContent(
-					require("./JsonpMainTemplate.runtime.js")
+					require("./JsonpMainTemplate.runtime")
 				)
 					.replace(/\/\/\$semicolon/g, ";")
 					.replace(/\$require\$/g, mainTemplate.requireFn)
 					.replace(
 						/\$crossOriginLoading\$/g,
-						crossOriginLoading
-							? `script.crossOrigin = ${JSON.stringify(crossOriginLoading)}`
-							: ""
+						crossOriginLoading ? JSON.stringify(crossOriginLoading) : "null"
 					)
 					.replace(/\$hotMainFilename\$/g, currentHotUpdateMainFilename)
 					.replace(/\$hotChunkFilename\$/g, currentHotUpdateChunkFilename)
@@ -563,11 +576,7 @@ ${globalObject}[${JSON.stringify(hotUpdateFunction)}] = ${runtimeSource}`;
 		);
 		mainTemplate.hooks.hash.tap("JsonpMainTemplatePlugin", hash => {
 			hash.update("jsonp");
-			hash.update("5");
-			hash.update(`${mainTemplate.outputOptions.globalObject}`);
-			hash.update(`${mainTemplate.outputOptions.chunkFilename}`);
-			hash.update(`${mainTemplate.outputOptions.jsonpFunction}`);
-			hash.update(`${mainTemplate.outputOptions.hotUpdateFunction}`);
+			hash.update("6");
 		});
 	}
 }
