@@ -19,8 +19,9 @@ module.exports = function() {
 	function hotDownloadManifest(requestTimeout) {
 		requestTimeout = requestTimeout || 10000;
 		return new Promise(function(resolve, reject) {
-			if (typeof XMLHttpRequest === "undefined")
+			if (typeof XMLHttpRequest === "undefined") {
 				return reject(new Error("No browser support"));
+			}
 			try {
 				var request = new XMLHttpRequest();
 				var requestPath = $require$.p + $hotMainFilename$;
