@@ -54,6 +54,20 @@ class WebWorkerMainTemplatePlugin {
 										)} + "`,
 									chunk: {
 										id: '" + chunkId + "',
+										hash: `" + ${JSON.stringify(chunkMaps.hash)}[chunkId] + "`,
+										hashWithLength(length) {
+											const shortChunkHashMap = Object.create(null);
+											for (const chunkId of Object.keys(chunkMaps.hash)) {
+												if (typeof chunkMaps.hash[chunkId] === "string") {
+													shortChunkHashMap[chunkId] = chunkMaps.hash[
+														chunkId
+													].substr(0, length);
+												}
+											}
+											return `" + ${JSON.stringify(
+												shortChunkHashMap
+											)}[chunkId] + "`;
+										},
 										contentHash: {
 											javascript: `" + ${JSON.stringify(
 												chunkMaps.contentHash.javascript
@@ -74,7 +88,10 @@ class WebWorkerMainTemplatePlugin {
 													shortContentHashMap
 												)}[chunkId] + "`;
 											}
-										}
+										},
+										name: `" + (${JSON.stringify(
+											chunkMaps.name
+										)}[chunkId]||chunkId) + "`
 									},
 									contentHashType: "javascript"
 								}) +
@@ -155,7 +172,7 @@ class WebWorkerMainTemplatePlugin {
 					)}];\n` +
 					`${globalObject}[${JSON.stringify(hotUpdateFunction)}] = ` +
 					Template.getFunctionContent(
-						require("./WebWorkerMainTemplate.runtime.js")
+						require("./WebWorkerMainTemplate.runtime")
 					)
 						.replace(/\/\/\$semicolon/g, ";")
 						.replace(/\$require\$/g, mainTemplate.requireFn)
@@ -167,12 +184,7 @@ class WebWorkerMainTemplatePlugin {
 		);
 		mainTemplate.hooks.hash.tap("WebWorkerMainTemplatePlugin", hash => {
 			hash.update("webworker");
-			hash.update("3");
-			hash.update(`${mainTemplate.outputOptions.publicPath}`);
-			hash.update(`${mainTemplate.outputOptions.filename}`);
-			hash.update(`${mainTemplate.outputOptions.chunkFilename}`);
-			hash.update(`${mainTemplate.outputOptions.chunkCallbackName}`);
-			hash.update(`${mainTemplate.outputOptions.globalObject}`);
+			hash.update("4");
 		});
 	}
 }
