@@ -109,12 +109,12 @@ describe("Compiler (caching)", () => {
 
 		// Copy over file since we"ll be modifying some of them
 		fs.mkdirSync(fixturePath);
-		fs
-			.createReadStream(path.join(__dirname, "fixtures", "a.js"))
-			.pipe(fs.createWriteStream(aFilepath));
-		fs
-			.createReadStream(path.join(__dirname, "fixtures", "c.js"))
-			.pipe(fs.createWriteStream(cFilepath));
+		fs.createReadStream(path.join(__dirname, "fixtures", "a.js")).pipe(
+			fs.createWriteStream(aFilepath)
+		);
+		fs.createReadStream(path.join(__dirname, "fixtures", "c.js")).pipe(
+			fs.createWriteStream(cFilepath)
+		);
 
 		fixtureCount++;
 		return {
