@@ -2,13 +2,13 @@
 "use strict";
 
 const path = require("path");
-const sinon = require("sinon");
 
 const webpack = require("../");
 const WebpackOptionsDefaulter = require("../lib/WebpackOptionsDefaulter");
 const MemoryFs = require("memory-fs");
 
 describe("Compiler", () => {
+	jest.setTimeout(20000);
 	function compile(entry, options, callback) {
 		const noOutputPath = !options.output || !options.output.path;
 		if (!options.mode) options.mode = "production";
@@ -86,7 +86,7 @@ describe("Compiler", () => {
 			expect(Object.keys(files)).toEqual(["/main.js"]);
 			const bundle = files["/main.js"];
 			expect(bundle).toMatch("function __webpack_require__(");
-			expect(bundle).toMatch("__webpack_require__(/*! ./a */ 0);");
+			expect(bundle).toMatch(/__webpack_require__\(\/\*! \.\/a \*\/ \d\);/);
 			expect(bundle).toMatch("./c.js");
 			expect(bundle).toMatch("./a.js");
 			expect(bundle).toMatch("This is a");
@@ -146,9 +146,9 @@ describe("Compiler", () => {
 	it("should compile a file with multiple chunks", done => {
 		compile("./chunks", {}, (stats, files) => {
 			expect(stats.chunks).toHaveLength(2);
-			expect(Object.keys(files)).toEqual(["/0.js", "/main.js"]);
+			expect(Object.keys(files)).toEqual(["/main.js", "/1.js"]);
 			const bundle = files["/main.js"];
-			const chunk = files["/0.js"];
+			const chunk = files["/1.js"];
 			expect(bundle).toMatch("function __webpack_require__(");
 			expect(bundle).toMatch("__webpack_require__(/*! ./b */");
 			expect(chunk).not.toMatch("__webpack_require__(/* ./b */");
@@ -181,19 +181,19 @@ describe("Compiler", () => {
 		});
 		describe("purgeInputFileSystem", () => {
 			it("invokes purge() if inputFileSystem.purge", done => {
-				const mockPurge = sinon.spy();
+				const mockPurge = jest.fn();
 				compiler.inputFileSystem = {
 					purge: mockPurge
 				};
 				compiler.purgeInputFileSystem();
-				expect(mockPurge.callCount).toBe(1);
+				expect(mockPurge.mock.calls.length).toBe(1);
 				done();
 			});
 			it("does NOT invoke purge() if !inputFileSystem.purge", done => {
-				const mockPurge = sinon.spy();
+				const mockPurge = jest.fn();
 				compiler.inputFileSystem = null;
 				compiler.purgeInputFileSystem();
-				expect(mockPurge.callCount).toBe(0);
+				expect(mockPurge.mock.calls.length).toBe(0);
 				done();
 			});
 		});
@@ -449,4 +449,69 @@ describe("Compiler", () => {
 			});
 		});
 	});
+	it("should flag watchMode as true in watch", function(done) {
+		const compiler = webpack({
+			context: __dirname,
+			mode: "production",
+			entry: "./c",
+			output: {
+				path: "/",
+				filename: "bundle.js"
+			}
+		});
+
+		compiler.outputFileSystem = new MemoryFs();
+
+		const watch = compiler.watch({}, err => {
+			if (err) return done(err);
+			expect(compiler.watchMode).toBeTruthy();
+			watch.close(() => {
+				expect(compiler.watchMode).toBeFalsy();
+				done();
+			});
+		});
+	});
+	it("should use cache on second run call", function(done) {
+		const compiler = webpack({
+			context: __dirname,
+			mode: "development",
+			devtool: false,
+			entry: "./fixtures/count-loader!./fixtures/count-loader",
+			output: {
+				path: "/"
+			}
+		});
+		compiler.outputFileSystem = new MemoryFs();
+		compiler.run(() => {
+			compiler.run(() => {
+				const result = compiler.outputFileSystem.readFileSync(
+					"/main.js",
+					"utf-8"
+				);
+				expect(result).toContain("module.exports = 0;");
+				done();
+			});
+		});
+	});
+	it("should call the failed-hook on error", done => {
+		const failedSpy = jest.fn();
+		const compiler = webpack({
+			bail: true,
+			context: __dirname,
+			mode: "production",
+			entry: "./missing",
+			output: {
+				path: "/",
+				filename: "bundle.js"
+			}
+		});
+		compiler.hooks.failed.tap("CompilerTest", failedSpy);
+		compiler.outputFileSystem = new MemoryFs();
+		compiler.run((err, stats) => {
+			expect(err).toBeTruthy();
+			expect(failedSpy).toHaveBeenCalledTimes(1);
+			expect(failedSpy).toHaveBeenCalledWith(err);
+			done();
+		});
+	});
 });
