@@ -1,12 +1,10 @@
-var should = require("should");
-
 it("should handle bound function expressions", function(done) {
 	require.ensure([], function(require) {
-		this.should.be.eql({ test: true });
+		expect(this).toEqual({ test: true });
 		require("./empty?test");
-		process.nextTick.should.have.type("function"); // check if injection still works
+		expect(process.nextTick).toBeTypeOf("function"); // check if injection still works
 		require.ensure([], function(require) {
-			this.should.be.eql({ test: true });
+			expect(this).toEqual({ test: true });
 			done();
 		}.bind(this));
 	}.bind({test: true}));
@@ -21,7 +19,7 @@ it("should handle require.ensure without function expression", function(done) {
 
 it("should parse expression in require.ensure, which isn't a function expression", function(done) {
 	require.ensure([], (function() {
-		require("./empty?require.ensure:test").should.be.eql({});
+		expect(require("./empty?require.ensure:test")).toEqual({});
 		return function f() {
 			done();
 		};
@@ -35,8 +33,8 @@ it("should accept a require.include call", function(done) {
 		value = require("./require.include");
 	});
 	setImmediate(function() {
-		should.strictEqual(value, "require.include");
-		value.should.be.eql("require.include");
+		expect(value).toBe("require.include");
+		expect(value).toBe("require.include");
 		done();
 	});
 });
