@@ -14,11 +14,11 @@ it("should not include a module with a weak dependency using context", function(
 	require(["./b"]);
 	require("./c");
 
-	resolveWeakA.should.exist;
-	resolveWeakB.should.exist;
-	resolveWeakC.should.exist;
+	expect(resolveWeakA).toBeDefined();
+	expect(resolveWeakB).toBeDefined();
+	expect(resolveWeakC).toBeDefined();
 
-	a.should.be.eql(false);
-	b.should.be.eql(false);
-	c.should.be.eql(true);
+	expect(a).toBe(false);
+	expect(b).toBe(false);
+	expect(c).toBe(true);
 });
