@@ -1,10 +1,10 @@
 it("should handle the coffee loader correctly", function() {
-	require("!coffee-loader!../_resources/script.coffee").should.be.eql("coffee test");
-	require("../_resources/script.coffee").should.be.eql("coffee test");
+	expect(require("!coffee-loader!../_resources/script.coffee")).toBe("coffee test");
+	expect(require("../_resources/script.coffee")).toBe("coffee test");
 });
 
 it("should handle literate coffee script correctly", function() {
-	require("!coffee-loader?literate!./script.coffee.md").should.be.eql("literate coffee test");
+	expect(require("!coffee-loader?literate!./script.coffee.md")).toBe("literate coffee test");
 });
 
 it("should generate valid code with cheap-source-map", function() {
