@@ -1,6 +1,6 @@
 module.exports = [
-	[/Module parse failed/, /dump-file\.txt/, /templates \^\\\.\\\/\.\*\$/],
+	[/Module parse failed/, /dump-file\.txt/, /templates sync \^\\\.\\\/\.\*\$/],
 	[/Critical dependency/, /templateLoader\.js/],
 	[/Critical dependency/, /templateLoaderIndirect\.js/],
 	[/Critical dependency/, /templateLoaderIndirect\.js/],
-];
\ No newline at end of file
+];
