@@ -1,5 +1,5 @@
 it("should replace a free var in a IIFE", function() {
 	(function(md) {
-		md.should.be.type("function");
+		expect(md).toBeTypeOf("function");
 	}(module.deprecate));
-});
\ No newline at end of file
+});
