@@ -1,14 +1,14 @@
 it("should fail on unsupported use of AMD require 1", function() {
-	(function() {
+	expect(function() {
 		var abc = ["./a", "./b"];
 		require(abc, function(a, b) {});
-	}).should.throw();
+	}).toThrowError();
 });
 
 it("should fail on unsupported use of AMD require 2", function() {
-	(function() {
+	expect(function() {
 		var abc = ["./a", "./b"];
 		function f(a, b) {}
 		require(abc, f);
-	}).should.throw();
+	}).toThrowError();
 });
