@@ -5,7 +5,7 @@ it("should resolve loaders relative to require", function() {
 		query: "?query",
 		prev: "module.exports = \"error\";"
 	});
-	expect(require("!./loaders/queryloader?query!./node_modules/subcontent/" + test + ".jade")).toEqual({
+	expect(require("!./loaders/queryloader?query!./node_modules/subcontent/" + test + ".pug")).toEqual({
 		resourceQuery: "",
 		query: "?query",
 		prev: "xyz: abc"
