@@ -1,3 +1,3 @@
 it("should load circular dependencies correctly", function() {
-	require("./circular").should.be.eql(1);
+	expect(require("./circular")).toBe(1);
 });
