@@ -3,5 +3,5 @@ export default 'a-default';
 export { btest } from "./b";
 
 export function atest() {
-	b.should.be.eql("b-default");
+	expect(b).toBe("b-default");
 }
