@@ -2,6 +2,6 @@ it("should have correct error code", function() {
 	try {
 		require("./fail");
 	} catch(e) {
-		e.code.should.be.eql("MODULE_NOT_FOUND");
+		expect(e.code).toBe("MODULE_NOT_FOUND");
 	}
-});
\ No newline at end of file
+});
