@@ -1,6 +1,6 @@
 import value, { named } from "./module";
 
 it("should have the correct values", function() {
-	value.should.be.eql("default");
-	named.should.be.eql("named");
+	expect(value).toBe("default");
+	expect(named).toBe("named");
 });
