@@ -6,9 +6,15 @@ module.exports = {
 			type: "require",
 			context: __dirname,
 			content: {
-				"./a.js": { id: 0 },
-				"./loader.js!./b.js": { id: 1 },
-				"./dir/c.js": { id: 2 }
+				"./a.js": {
+					id: 0
+				},
+				"./loader.js!./b.js": {
+					id: 1
+				},
+				"./dir/c.js": {
+					id: 2
+				}
 			}
 		})
 	]
