@@ -1,3 +1,3 @@
 it("should correctly pass complex query object with remaining request", function() {
-	require("./a").should.be.eql("ok");
+	expect(require("./a")).toBe("ok");
 });
