@@ -18,35 +18,35 @@ const banner = parseBanner(source)
 const REGEXP_HASH = /^[A-Za-z0-9]{20}$/
 
 it("should interpolate file hash in chunk banner", () => {
-	REGEXP_HASH.test(banner["hash"]).should.be.true;
+	expect(REGEXP_HASH.test(banner["hash"])).toBe(true);
 });
 
 it("should interpolate chunkHash in chunk banner", () => {
-	REGEXP_HASH.test(banner["chunkhash"]).should.be.true;
+	expect(REGEXP_HASH.test(banner["chunkhash"])).toBe(true);
 });
 
 it("should interpolate file into chunk banner", () => {
-	banner["file"].should.equal("dist/banner.js");
+	expect(banner["file"]).toBe("dist/banner.js");
 });
 
 it("should interpolate name in chunk banner", () => {
-	banner["name"].should.equal("dist/banner");
+	expect(banner["name"]).toBe("dist/banner");
 });
 
 it("should interpolate basename in chunk banner", () => {
-	banner["filebase"].should.equal("banner.js");
+	expect(banner["filebase"]).toBe("banner.js");
 });
 
 it("should interpolate query in chunk banner", () => {
-	banner["query"].should.equal("?value");
+	expect(banner["query"]).toBe("?value");
 });
 
 it("should parse entry into file in chunk banner", () => {
-	banner["file"].should.not.equal(banner["filebase"]);
+	expect(banner["file"]).not.toBe(banner["filebase"]);
 });
 
 it("should parse entry into name in chunk banner", () => {
-	banner["filebase"].should.not.equal(banner["name"]);
+	expect(banner["filebase"]).not.toBe(banner["name"]);
 });
 
 require.include("./test.js");
