@@ -12,9 +12,14 @@ module.exports = {
 		filename: "[name].js"
 	},
 	plugins: [
+		new webpack.BannerPlugin("banner is a string"),
+		new webpack.BannerPlugin(() => "banner is a function"),
 		new webpack.BannerPlugin({
 			banner: "A test value",
 			exclude: ["vendors.js"]
+		}),
+		new webpack.BannerPlugin({
+			banner: ({ chunk }) => `multiline\nbanner\n${chunk.name}`
 		})
 	]
 };
