@@ -1,4 +1,4 @@
 var fs = require("fs");
 var source = fs.readFileSync(__filename, "utf-8");
 var match = /sourceMappingURL\s*=\s*(.*)/.exec(source);
-match[1].should.be.eql("c.js.map");
\ No newline at end of file
+expect(match[1]).toBe("c.js.map");
