@@ -1,7 +1,8 @@
 module.exports = function(done, options, callback) {
-	return function(stats) {
+	return function(err, stats) {
+		if (err) return done(err);
 		module.hot.check(options || true).then(() => {
-			if(callback)
+			if (callback)
 				callback(stats);
 		}).catch((err) => {
 			done(err);
