@@ -1,8 +1,12 @@
 module.exports = {
+	mode: "production",
 	entry: "./index",
 	output: {
 		filename: "bundle.js"
 	},
+	optimization: {
+		concatenateModules: false
+	},
 	stats: {
 		chunkModules: false,
 		modules: true,
