@@ -1,4 +1,4 @@
 it("should detect changes in a context", function() {
 	var context = require.context("./directory");
-	context.keys().length.should.be.eql((+WATCH_STEP) % 3 * 2);
+	expect(context.keys().length).toBe((+WATCH_STEP) % 3 * 2);
 });
